/* ============================================================
 * File  : mainfrm.cpp
 * Author: Stephane Gibault
 * Date  : Sun Feb 4 2007
 * Description :
 *
 * 
 *  (C) 2007 by Stephane Gibault
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include <QtGui>
#include <QFileDialog>
#include <QProcess>
#include "mainfrm.h"
#include "tetrahedron.h"
#include <Q3FileDialog>

class H_Slider_Theme_2 : public QWindowsStyle
{
	public:
	const QImage IMG_SLIDER_HANDLE;
	const QImage IMG_SLIDER_GROOVE;

  	H_Slider_Theme_2 ()
    		: IMG_SLIDER_HANDLE (":/new/prefix1/Interface/slider_fond_2.png"),
      		IMG_SLIDER_GROOVE (":/new/prefix1/Interface/slider_fond_3.png")
  	{
  	};
  
  	virtual void drawComplexControl (ComplexControl control,
                   const QStyleOptionComplex* option,
                   QPainter* painter,
                   const QWidget* widget) const;
};

void
	H_Slider_Theme_2::drawComplexControl (ComplexControl control,
		const QStyleOptionComplex* option,
        	QPainter* painter,
        	const QWidget* widget) const
{
  		switch (control)
    		{
    			case (QStyle::CC_Slider):
      				if (const QStyleOptionSlider *sliderOption = qstyleoption_cast<const QStyleOptionSlider *>(option)) 
    				{
      					QRect groove = QCommonStyle::subControlRect (CC_Slider, sliderOption, SC_SliderGroove, widget);
     					 QRect handle = QCommonStyle::subControlRect (CC_Slider, sliderOption, SC_SliderHandle, widget);
      
      					if ((sliderOption->subControls & SC_SliderGroove) && groove.isValid()) 
        				{
          				painter->drawImage (QRect (groove.x (), groove.y (), 
                     			groove.width (),                  			H_Slider_Theme_2::IMG_SLIDER_GROOVE.height ()), 
                  			H_Slider_Theme_2::IMG_SLIDER_GROOVE);
        				}
      
      					if (sliderOption->subControls & SC_SliderHandle) 
       					{
						if ( handle.x () > 0 )
						{
							painter->drawImage (0, -1, H_Slider_Theme_2::IMG_SLIDER_HANDLE, 0, 0, handle.x () , handle.y (), Qt::AutoColor);
						}
						painter->drawImage (handle.x () - 7, handle.y (), H_Slider_Theme_2::IMG_SLIDER_HANDLE, 102, 0, 20, handle.y (), Qt::AutoColor);
        				}
    				}
      				break;
    				default:
      				QWindowsStyle::drawComplexControl (control, option, painter, widget);
    		}
}

class Preview : public QLabel, public Q3FilePreview
{
	public:
       		Preview(QWidget *parent=0) : QLabel (parent) {}

       		void previewUrl(const Q3Url &u)
       		{
           		QString path = u.path();
           		QPixmap pix(path);

           		if (pix.isNull())
			{
               			setText("");
			}
           		else
			{
				if ( pix.height() > pix.width() )
				{
					QPixmap pix2 = pix.scaledToHeight ( 200, Qt::FastTransformation );
					setPixmap(pix2);
				}
				else
				{
               				QPixmap pix2 = pix.scaledToWidth ( 200, Qt::FastTransformation );
					setPixmap(pix2);
				}
			}
       		}
};

mainfrm::mainfrm(QWidget *parent) : QDialog(parent)
{
	setupUi(this);
	Tetrahedron *mygl = new Tetrahedron(frame_ed3d);
	//
	pntmygl = mygl;
	pntmygl->txt_sur_image = "";
	pntmygl->tool = 0;
	pntmygl->effet_titre = 0;
	pntmygl->x_titre = -1.8;
	pntmygl->v_titre = 1;
	curframe = menu_projet;
	frame_ed3d->setDisabled(true);
	path_photos_import = "~";
	pntmygl->mycolor.setRgb(255,255,255);
	zik_number = 0;
	zik_1->hide();
	total_audio = 0;
	must_redraw = 0;
	//
	gl_fond.load(":/new/prefix1/Interface/fond.png");
	wg_comment.load(":/new/prefix1/Interface/comment.png");
	wg_diapositive.load(":/new/prefix1/Interface/diapositive.png");
	//
	H_Slider_Theme_2* style_hslider2 = new H_Slider_Theme_2();
	dial_opacity->setStyle (style_hslider2);
	dial_opacity_2->setStyle (style_hslider2);
	dial_opacity_slide->setStyle (style_hslider2);
	//
	stick_menu->setGeometry(106,7,98,32);
	M_BT_PROJ->setEnabled(true);
	M_BT_IMG->setDisabled(true);
	M_BT_IMG->raise();
	curframe = menu_images;
	menu_images->setGeometry(0,50,411,471);
	menu_images->show();

	/*stick_menu->setGeometry(10,7,98,32);
	M_BT_PROJ->raise();*/
	menu_projet->hide();
	menu_projet->setGeometry(0,50,391,471);
	frame_zik->hide();
	frame_zik->setGeometry(0,50,391,471);
	//menu_images->hide();
	//menu_images->setGeometry(0,50,391,471);
	frame_parameters->hide();
	frame_parameters->setGeometry(0,50,391,471);
	frame_telecomm->hide();
	frame_telecomm->setGeometry(0,50,391,471);
	param_encoding->hide();
	param_encoding->setGeometry(0,50,391,471);

	frame_topmenu->setDisabled(true);
	frame_toptimeline->setDisabled(true);
	contain_timeline->setDisabled(true);
	frame_fade->setDisabled(true);
	img_selection->hide();
	frame_param_trans->hide();
	bt_img_effects->setDisabled(true);
	bt_fond->setDisabled(true);
	bt_screenshot->setDisabled(true);
	bt_supp_zik->setDisabled(true);
	param_diapo->setDisabled(true);
	bt_save_proj->setDisabled(true);
	bt_supprime_diapo->setDisabled(true);
	bt_param_import->setEnabled(true);
	bt_copy_all->setDisabled(true);
	bt_paste_all->setDisabled(true);
	bt_sync->setDisabled(true);
	bt_play->setDisabled(true);
	bt_play_all->setDisabled(true);
	bt_stop->setDisabled(true);
	bt_start->setDisabled(true);
	bt_end->setDisabled(true);
	group_support->setDisabled(true);
	plane->setChecked(true);
	//
    	lst_transitions->insertItem(0,tr("Pas de transitions"));
    	lst_transitions->insertItem(1,tr("Fondu enchaine"));
	//
    	lst_transitions_2->insertItem(0,tr("Pas de transitions"));
    	lst_transitions_2->insertItem(1,tr("Transition aleatoire"));
   	lst_transitions_2->insertItem(2,tr("Fondu enchaine"));
	//
	comboposlegende->insertItem(0,tr("Statique bas"));
	comboposlegende->insertItem(1,tr("Statique haut"));
	comboposlegende->insertItem(2,tr("Statique milieu"));
	comboposlegende->insertItem(3,tr("Mouvement bas"));
	comboposlegende->insertItem(4,tr("Bas fond noir"));
	//
	comboqualite->insertItem(0,tr("Haute"));
	comboqualite->insertItem(1,tr("Normale"));
	comboqualite->insertItem(2,tr("Basse"));
	comboqualite->insertItem(3,tr("Tres basse"));
	comboqualite->setCurrentIndex(1);
	//
	combocodec->insertItem(0,"MPEG2");
	combocodec->insertItem(1,"AVI DV");
	combocodec->setCurrentIndex(0);
	//
	comboeffets->insertItem(0,tr("Aucun"));
	comboeffets->setCurrentIndex(0);
	//
	list_effets_anim->insertItem(0,tr("Standard"));
	list_effets_anim->insertItem(1,tr("Chute 1"));
	list_effets_anim->insertItem(2,tr("Panoramique horizontal"));
	list_effets_anim->insertItem(3,tr("Panoramique vertical"));
	list_effets_anim->insertItem(4,tr("Toupie"));
	list_effets_anim->insertItem(5,tr("Redresser"));
	list_effets_anim->insertItem(6,tr("Zoom simple"));
	list_effets_anim->setCurrentIndex(0);
	pntmygl->iseffect = 0;
	// ---> Chute
	table_models[0][0] = 0.0f;
	table_models[0][1] = 0.0f;
	table_models[0][2] = -3.8f;
	table_models[0][3] = 0.0f;
	table_models[0][4] = 0.0f;
	table_models[0][5] = 0.0f;
	table_models[0][6] = 0.0f;
	table_models[0][7] = 0.0f;
	table_models[0][8] = -16.9f;
	table_models[0][9] = 0.0f;
	table_models[0][10] = -3.0f;
	table_models[0][11] = 19.0f;
	// ---> Panoramique horizontal
	table_models[1][0] = -1.21f;
	table_models[1][1] = -0.0f;
	table_models[1][2] = -2.1f;
	table_models[1][3] = 0.0f;
	table_models[1][4] = 0.0f;
	table_models[1][5] = 0.0f;
	table_models[1][6] = 1.21f;
	table_models[1][7] = 0.0f;
	table_models[1][8] = -2.1f;
	table_models[1][9] = 0.0f;
	table_models[1][10] = 0.0f;
	table_models[1][11] = 0.0f;
	// ---> Panoramique vertical
	table_models[2][0] = 0.029f;
	table_models[2][1] = -0.96f;
	table_models[2][2] = -2.1f;
	table_models[2][3] = 0.0f;
	table_models[2][4] = 0.0f;
	table_models[2][5] = 0.0f;
	table_models[2][6] = 0.029f;
	table_models[2][7] = 0.96f;
	table_models[2][8] = -2.1f;
	table_models[2][9] = 0.0f;
	table_models[2][10] = 0.0f;
	table_models[2][11] = 0.0f;
	// ---> Toupie
	table_models[3][0] = 0.0f;
	table_models[3][1] = 0.0f;
	table_models[3][2] = -13.7f;
	table_models[3][3] = 0.0f;
	table_models[3][4] = -90.0f;
	table_models[3][5] = 0.0f;
	table_models[3][6] = 0.0f;
	table_models[3][7] = 0.0f;
	table_models[3][8] = -3.8f;
	table_models[3][9] = 0.0f;
	table_models[3][10] = 0.0f;
	table_models[3][11] = 0.0f;
	// ---> Redresser
	table_models[4][0] = -0.04f;
	table_models[4][1] = -0.67f;
	table_models[4][2] = -3.8f;
	table_models[4][3] = -78.0f;
	table_models[4][4] = 0.0f;
	table_models[4][5] = 0.0f;
	table_models[4][6] = 0.0f;
	table_models[4][7] = 0.0f;
	table_models[4][8] = -3.8f;
	table_models[4][9] = 0.0f;
	table_models[4][10] = 0.0f;
	table_models[4][11] = 0.0f;
	// ---> Zoom simple
	table_models[5][0] = 0.0f;
	table_models[5][1] = 0.0f;
	table_models[5][2] = -16.9f;
	table_models[5][3] = 0.0f;
	table_models[5][4] = 0.0f;
	table_models[5][5] = 0.0f;
	table_models[5][6] = 0.0f;
	table_models[5][7] = 0.0f;
	table_models[5][8] = -3.8f;
	table_models[5][9] = 0.0f;
	table_models[5][10] = 0.0f;
	table_models[5][11] = 0.0f;
	//
	nbre_photos = -1;
	current_diapo = -1;
	mygl->setGeometry(10,10,505,388);
	// ******************************
	// *** Decelration des timers ***
	// ******************************
 	mplayer_timer = new QTimer(this);
	//
	connect(this, SIGNAL(finished( int )),this, SLOT(f_end_mainfrm( int )));

	connect(bt_param_trans, SIGNAL(clicked()),this, SLOT(f_affiche_param_transitions()));
	connect(bt_valid_ptrans, SIGNAL(clicked()),this, SLOT(f_valid_ptrans()));
	connect(slider_smooth, SIGNAL(valueChanged(int)),this, SLOT(f_gen_preview()));
	connect(inverser, SIGNAL(stateChanged(int)),this, SLOT(f_gen_preview()));

	connect(bt_find_library, SIGNAL(clicked()),this, SLOT(f_path_library()));
	connect(bt_valid_swap, SIGNAL(clicked()),this, SLOT(f_valid_swap()));
	connect(bt_cancel_swap, SIGNAL(clicked()),this, SLOT(f_cancel_swap()));
	connect(bt_swap, SIGNAL(clicked()),this, SLOT(f_swap()));
	connect(plane, SIGNAL(clicked()),this, SLOT(f_plane()));
	connect(flag, SIGNAL(clicked()),this, SLOT(f_flag()));
	connect(cube, SIGNAL(clicked()),this, SLOT(f_cube()));

	connect(bt_ajout_effet, SIGNAL(clicked()),this, SLOT(f_ajout_effet()));
	connect(bt_remove_effet, SIGNAL(clicked()),this, SLOT(f_remove_effet()));
	connect(btcancelextract, SIGNAL(clicked()),this, SLOT(f_cancel_extract()));
	connect(bt_find_video, SIGNAL(clicked()),this, SLOT(f_find_video()));
	connect(btgoextract, SIGNAL(clicked()),this, SLOT(f_go_extract()));
	connect(bt_find_out, SIGNAL(clicked()),this, SLOT(f_find_out()));
	connect(bt_launch_gimp, SIGNAL(clicked()),this, SLOT(f_launch_gimp()));
	connect(bt_remove_photo_2, SIGNAL(clicked()),this, SLOT(supp_diapo()));
	//
	connect(bt_change_color_fog, SIGNAL(clicked()),this, SLOT(f_change_color_fog()));
	connect(bt_debut, SIGNAL(clicked()),this, SLOT(md_start()));
	connect(bt_fin, SIGNAL(clicked()),this, SLOT(md_fin()));
	connect(bt_play, SIGNAL(clicked()),this, SLOT(start_play()));
	connect(bt_play_all, SIGNAL(clicked()),this, SLOT(start_play_all()));
	connect(bt_stop, SIGNAL(clicked()),this, SLOT(stop_play()));
	connect(bt_start, SIGNAL(clicked()),this, SLOT(sl_go_start()));
	connect(bt_end, SIGNAL(clicked()),this, SLOT(sl_go_end()));
	connect(bt_fond, SIGNAL(clicked()),this, SLOT(f_change_fond()));
	connect(check_fog, SIGNAL(stateChanged(int)),this, SLOT(f_brouillard(int)));
	connect(check_backanim, SIGNAL(stateChanged(int)),this, SLOT(f_backanim(int)));
	connect(slider_factor, SIGNAL(valueChanged(int)),this, SLOT(f_factor(int)));
	connect(dial_opacity, SIGNAL(valueChanged(int)),this, SLOT(f_opacity(int)));
	connect(dial_opacity_2, SIGNAL(valueChanged(int)),this, SLOT(f_opacity_2(int)));
	connect(dial_opacity_slide, SIGNAL(valueChanged(int)),this, SLOT(f_opacity_slide(int)));
	connect(dial_percent_blending, SIGNAL(valueChanged(int)),this, SLOT(f_percent_blending(int)));
	connect(dial_percent_blending_2, SIGNAL(valueChanged(int)),this, SLOT(f_percent_blending_2(int)));

	connect(bt_add_photo, SIGNAL(clicked()),this, SLOT(load_photo()));
	connect(bt_supprime_diapo, SIGNAL(clicked()),this, SLOT(supp_diapo()));
	connect(spindurdiapo, SIGNAL(valueChanged(int)),this, SLOT(f_changedur(int)));
	connect(spindurdiapo_2, SIGNAL(valueChanged(int)),this, SLOT(f_changedur_2(int)));

	connect(effet_hmirror, SIGNAL(clicked()),this, SLOT(f_hmirror()));
	connect(effet_vmirror, SIGNAL(clicked()),this, SLOT(f_vmirror()));
	connect(effet_pcontraste, SIGNAL(clicked()),this, SLOT(f_pcontraste()));
	connect(effet_mcontraste, SIGNAL(clicked()),this, SLOT(f_mcontraste()));
	connect(effet_sepia, SIGNAL(clicked()),this, SLOT(f_sepia()));
	connect(effet_negate, SIGNAL(clicked()),this, SLOT(f_negate()));
	connect(effet_blur, SIGNAL(clicked()),this, SLOT(f_blur()));
	connect(effet_sharpen, SIGNAL(clicked()),this, SLOT(f_sharpen()));
	connect(effet_edge, SIGNAL(clicked()),this, SLOT(f_edge()));
	connect(effet_emboss, SIGNAL(clicked()),this, SLOT(f_emboss()));
	connect(effet_paint, SIGNAL(clicked()),this, SLOT(f_paint()));
	connect(effet_gris, SIGNAL(clicked()),this, SLOT(f_gris()));
	connect(effet_rneg, SIGNAL(clicked()),this, SLOT(f_rneg()));
	connect(effet_rpos, SIGNAL(clicked()),this, SLOT(f_rpos()));
	connect(effet_fade, SIGNAL(clicked()),this, SLOT(f_fade()));

	connect(bt_copy_all, SIGNAL(clicked()),this, SLOT(f_copy()));
	connect(bt_paste_all, SIGNAL(clicked()),this, SLOT(f_paste()));
	connect(bt_raz, SIGNAL(clicked()),this, SLOT(f_raz()));
	connect(bt_close_effets, SIGNAL(clicked()),this, SLOT(f_close_effets()));
	connect(bt_open_comment, SIGNAL(clicked()),this, SLOT(f_open_comment()));

	connect(bt_img_effects, SIGNAL(clicked()),this, SLOT(f_aff_effects()));

	connect(bt_screenshot, SIGNAL(clicked()),this, SLOT(f_screenshot()));
	connect(bt_param_import, SIGNAL(clicked()),this, SLOT(f_affiche_parametres()));
	connect(bt_deplace_image_gauche, SIGNAL(clicked()),this, SLOT(f_dep_gauche()));
	connect(bt_deplace_image_droite, SIGNAL(clicked()),this, SLOT(f_dep_droite()));

	connect(bt_start_encoding, SIGNAL(clicked()),this, SLOT(f_generer_diapo()));

	connect(scroll_timeline, SIGNAL(valueChanged(int)),this, SLOT(f_scroll_timeline(int)));
	connect(lst_transitions, SIGNAL(currentIndexChanged(int)),this, SLOT(f_transition_changed(int)));
	connect(spindurtrans, SIGNAL(valueChanged(int)),this, SLOT(f_transition_duree_changed(int)));
	connect(spindurpausefirst, SIGNAL(valueChanged(int)),this, SLOT(f_durp_deb(int)));
	connect(spindurpauselast, SIGNAL(valueChanged(int)),this, SLOT(f_durp_end(int)));

	connect(comboeffets, SIGNAL(currentIndexChanged(int)),this, SLOT(f_apply_effets(int)));
	connect(comboposlegende, SIGNAL(currentIndexChanged(int)),this, SLOT(f_pos_leg(int)));
	connect(bt_add_zik, SIGNAL(clicked()),this, SLOT(f_add_zik()));
	connect(bt_supp_zik, SIGNAL(clicked()),this, SLOT(f_sup_zik()));
	connect(bt_sync, SIGNAL(clicked()),this, SLOT(f_sync()));

	connect(bt_tool_scale, SIGNAL(clicked()),this, SLOT(f_chg_tool_a()));
	connect(bt_tool_grab, SIGNAL(clicked()),this, SLOT(f_chg_tool_b()));
	connect(bt_tool_rotateX, SIGNAL(clicked()),this, SLOT(f_chg_tool_c()));
	connect(bt_tool_rotateY, SIGNAL(clicked()),this, SLOT(f_chg_tool_d()));
	connect(bt_tool_rotateZ, SIGNAL(clicked()),this, SLOT(f_chg_tool_e()));
	connect(bt_tool_rotateL, SIGNAL(clicked()),this, SLOT(f_chg_tool_f()));

	connect(bt_save_proj, SIGNAL(clicked()),this, SLOT(f_save_proj()));
	connect(bt_open_proj, SIGNAL(clicked()),this, SLOT(f_open_proj()));
	
	connect(bt_police, SIGNAL(clicked()),this, SLOT(f_police()));
	connect(bt_couleur, SIGNAL(clicked()),this, SLOT(f_couleur()));
	connect(legende_image, SIGNAL(textChanged(QString)),this, SLOT(f_chg_leg(QString)));

	connect(&myprocess_1, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(end_process(int, QProcess::ExitStatus)));
	connect(&myprocess_1, SIGNAL(readyReadStandardOutput()), this, SLOT(lecture_console_magick()));
	connect(&myprocess_2, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(end_encoding(int, QProcess::ExitStatus)));
	connect(&myprocess_2, SIGNAL(readyReadStandardError()), this, SLOT(lecture_console_encoding()));
	connect(&myprocess_3, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(end_encoding_audio(int, QProcess::ExitStatus)));
	connect(&myprocess_3, SIGNAL(readyReadStandardError()), this, SLOT(lecture_console_out_audio_encoding()));
	connect(&myprocess_4, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(end_all_audio(int, QProcess::ExitStatus)));
	connect(&myprocess_5, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(end_zik_import(int, QProcess::ExitStatus)));
	connect(&myprocess_5, SIGNAL(readyReadStandardOutput()), this, SLOT(lecture_console_import_zik()));
	connect(&myprocess_7, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(end_convert_video(int, QProcess::ExitStatus)));
	connect(&myprocess_7, SIGNAL(readyReadStandardOutput()), this, SLOT(lecture_convert_video()));
	connect(&myprocess_8, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(end_extract_video(int, QProcess::ExitStatus)));
	connect(&myprocess_8, SIGNAL(readyReadStandardOutput()), this, SLOT(lecture_extract_video()));
	connect(&myprocess_9, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(end_save_project(int, QProcess::ExitStatus)));

	connect(M_BT_PROJ, SIGNAL(clicked()),this, SLOT(f_aff_m_proj()));
	connect(M_BT_IMG, SIGNAL(clicked()),this, SLOT(f_aff_m_img()));
	connect(M_BT_PARAM, SIGNAL(clicked()),this, SLOT(f_aff_m_param()));
	connect(M_BT_EXPORT, SIGNAL(clicked()),this, SLOT(f_aff_m_export()));
	connect(M_BT_ZIK, SIGNAL(clicked()),this, SLOT(f_aff_m_zik()));
	connect(M_BT_3D, SIGNAL(clicked()),this, SLOT(f_aff_m_3d()));

	connect(bt_close_param_import, SIGNAL(clicked()),this, SLOT(f_close_param_import()));
	connect(bt_save_param, SIGNAL(clicked()),this, SLOT(f_save_param_manslide()));
	connect(bt_preview, SIGNAL(clicked()),this, SLOT(f_preview()));
	connect(bt_originale, SIGNAL(clicked()),this, SLOT(f_preview_originale()));
	connect(bt_modifiee, SIGNAL(clicked()),this, SLOT(f_preview_modifiee()));
	connect(bt_start_new, SIGNAL(clicked()),this, SLOT(f_start_new()));

	connect(bt_choix_modele, SIGNAL(clicked()),this, SLOT(f_aff_modele()));
	connect(bt_close_model_anim, SIGNAL(clicked()),this, SLOT(f_close_modele()));
	connect(bt_valid_effet, SIGNAL(clicked()),this, SLOT(f_valide_modele()));
	connect(bt_supp_comment, SIGNAL(clicked()),this, SLOT(f_supp_comment()));
	connect(list_effets_anim, SIGNAL(currentIndexChanged(int)),this, SLOT(f_model_changed(int)));

	// *** SIGNAUX MPLAYER ***
	connect(player_progress, SIGNAL(sliderReleased()),this, SLOT(player_percent_change()));
	connect(player_progress, SIGNAL(sliderPressed()),this, SLOT(player_start_percent_change()));
	connect(bt_play_tv, SIGNAL(clicked()),this, SLOT(player_play_video()));
	connect(bt_close_player, SIGNAL(clicked()),this, SLOT(f_close_player()));

        connect(mplayer_timer, SIGNAL(timeout()), this, SLOT(player_current_percent()));

	connect(&mplayerProcess, SIGNAL(readyReadStandardOutput()), this, SLOT(player_read_stdout()));
	connect(&mplayerProcess, SIGNAL(finished(int, QProcess::ExitStatus)),
                        this, SLOT(player_end(int, QProcess::ExitStatus)));

	// *** FIRST LAUNCH ***
	menu_projet->setDisabled(true);
	frame_topmenu->setDisabled(true);
	contain_timeline->setDisabled(true);
	QDir currentDir = QDir::homePath();
	QFile configfile( currentDir.path() + "/.manslide.cnf" );
	if (configfile.open(QFile::ReadOnly)) 
	{
		QString wtmpvar1;
		QByteArray newData;
		newData = configfile.readLine(0);
		wtmpvar1 = QString::fromLocal8Bit(newData);
		
		if ( wtmpvar1.mid(0,2) == "R6" )
		{
			newData = configfile.readLine(0);
			newData = configfile.readLine(0);
			wtmpvar1 = QString::fromLocal8Bit(newData);
			int myind = wtmpvar1.length();
			wg_cpu = wtmpvar1.mid(0,myind - 1);
			newData = configfile.readLine(0);
			wtmpvar1 = QString::fromLocal8Bit(newData);
			myind = wtmpvar1.length();
			wg_library = wtmpvar1.mid(0,myind - 1);
			pntmygl->wg_tet_library = wg_library;
			configfile.close();
			//
			QDir tmpdir(QDir::homePath() + "/.TmpManSlide");
			if ( tmpdir.exists() == false )
			{
				QDir credir(QDir::homePath());
				if ( credir.mkpath(".TmpManSlide") == true )
				{
					wpathprojet = QDir::homePath() + "/.TmpManSlide";
					pntmygl->path_render = wpathprojet;
					bt_save_proj->setDisabled(true);
					bt_add_photo->setEnabled(true);
					bt_supprime_diapo->setDisabled(true);
					bt_param_import->setEnabled(true);
					bt_open_proj->setEnabled(true);
					menu_projet->setEnabled(true);
					frame_topmenu->setEnabled(true);
					contain_timeline->setEnabled(true);
				}
				else
				{
					QMessageBox::information(this, "Manslide", tr("Manslide n a pas reussi a creer un repertoire temporaire dans votre dossier tmp : ") + QDir::homePath());
				}
			}
			else
			{
				wpathprojet = QDir::homePath() + "/.TmpManSlide";
				pntmygl->path_render = wpathprojet;
				bt_save_proj->setDisabled(true);
				bt_add_photo->setEnabled(true);
				bt_supprime_diapo->setDisabled(true);
				bt_param_import->setEnabled(true);
				bt_open_proj->setEnabled(true);
				menu_projet->setEnabled(true);
				frame_topmenu->setEnabled(true);
				contain_timeline->setEnabled(true);
			}
			//
			tmpdir.setPath(wg_library + "BIB_ManSlide/Effects/");
			QStringList filters;
			filters << "*.*";
			int positem = 1;
			QDir subdir;
			QString wlfile;
			foreach (wlfile, tmpdir.entryList(QDir::Dirs | QDir::NoDotAndDotDot))
			{
				comboeffets->insertItem(positem, wlfile);
				subdir.setPath(wg_library + "/BIB_ManSlide/Effects/" + wlfile);
				pntmygl->table_effets[positem][0] = wlfile;
				pntmygl->table_effets[positem][1] = QString::number(subdir.count());
				positem = positem + 1;
			}
			//
			tmpdir.setPath(wg_library + "BIB_ManSlide/Luma/");
			filters << "*.*";
			positem = 2;
			QPixmap transpix;
			QPixmap transpix_2;
			lst_transitions->setItemIcon(1, QIcon(wg_library + "BIB_ManSlide/Luma/crossfade.png"));
			lst_transitions_2->setItemIcon(2, QIcon(wg_library + "BIB_ManSlide/Luma/crossfade.png"));
			foreach (wlfile, tmpdir.entryList(QDir::Files))
			{
				if ( positem < 399 )
				{
					if ( wlfile != "crossfade.png" )
					{
						transpix.load(wg_library + "BIB_ManSlide/Luma/" + wlfile);
						transpix_2 = transpix.scaled(40, 30, Qt::IgnoreAspectRatio, Qt::FastTransformation);
    						lst_transitions->insertItem(positem,wlfile.mid(0,wlfile.length() - 4));
						lst_transitions->setItemIcon(positem, QIcon(transpix_2));
    						lst_transitions_2->insertItem(positem+1,wlfile.mid(0,wlfile.length() - 4));
						lst_transitions_2->setItemIcon(positem+1, QIcon(transpix_2));
						table_transitions[positem] = wg_library + "BIB_ManSlide/Luma/" + wlfile;
						positem = positem + 1;
					}
				}
			}
		}
		else
		{
			configfile.close();
			cblangue->insertItem(0,"Francais");
			cblangue->insertItem(1,"English");
			cblangue->insertItem(2,"Catalan");
			cblangue->insertItem(3,"Polish");
			cblangue->insertItem(4,"Russian");
			cblangue->insertItem(5,"Italian");
			cblangue->insertItem(6,"Romanian");
			cblangue->insertItem(7,"German");
			cblangue->insertItem(8,"Dutch");
			cblangue->insertItem(9,"Espagnol");
			cblangue->insertItem(10,"Hungarian");
			cblangue->setCurrentIndex(0);
			frame_first_time->setGeometry(214,121,571,441);
			frame_first_time->show();
			frame_first_time->raise();
		}
	}
	else
	{
		cblangue->insertItem(0,"Francais");
		cblangue->insertItem(1,"English");
		cblangue->insertItem(2,"Catalan");
		cblangue->insertItem(3,"Polish");
		cblangue->insertItem(4,"Russian");
		cblangue->insertItem(5,"Italian");
		cblangue->insertItem(6,"Romanian");
		cblangue->insertItem(7,"German");
		cblangue->insertItem(8,"Dutch");
		cblangue->insertItem(9,"Espagnol");
		cblangue->insertItem(10,"Hungarian");
		cblangue->setCurrentIndex(0);
		//
		frame_first_time->setGeometry(214,121,571,441);
		frame_first_time->show();
		frame_first_time->raise();
	}
}

void mainfrm::f_close_player()
{
	player_end(0, QProcess::NormalExit);
	if ( ispreview == 1 || ispreview == 9 )
	{
		QString wl_tmp_1 = wpathprojet + "/MSpreview.mpg";
		if ( QFile::remove ( wl_tmp_1 ) == false )
		{
			//qDebug() << "ERROR REMOVING FILE FROM TMP DIRECTORY ...";
		}
	}
}

void mainfrm::f_remove_effet()
{
	if ( comboeffets->currentIndex() > -1)
	{
		int result = QMessageBox::information(this, "Manslide", tr("Voulez vous vraiment supprimer cet effet : ") + comboeffets->currentText() , tr("Oui"), tr("Non"), 0, 1 );
		if (result == 0)
		{
			QString thedir(wg_library + "BIB_ManSlide/Effects/" + comboeffets->currentText());
			QString program = "rm";
       			QStringList arguments;
			arguments << "-rf";
			ispreview = 5;
       			arguments << thedir;
       			myprocess_9.start( program, arguments );
		}
	}
}

void mainfrm::f_plane()
{
	table_photos[current_diapo][27] = "0";
	pntmygl->type3D = 0;
	pntmygl->updateGL();
}

void mainfrm::f_flag()
{
	table_photos[current_diapo][27] = "1";
	pntmygl->type3D = 1;
	pntmygl->updateGL();
}

void mainfrm::f_cube()
{
	table_photos[current_diapo][27] = "2";
	pntmygl->type3D = 2;
	pntmygl->updateGL();
}

void mainfrm::f_path_library()
{
	QString mydir = QFileDialog::getExistingDirectory( this, tr("Choisissez un repertoire pour la bibliotheque d'effets video"), "~", QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
        if ( mydir.isNull() )
        {
        }
	else
	{
		path_library->setText(mydir);
	}
}

void mainfrm::f_launch_gimp()
{
	QString program = "gimp";
       	QStringList arguments;
	ispreview = 2;
	this->setDisabled(true);
       	arguments << wpathprojet + "/" + table_photos[current_diapo][0];
       	myprocess_9.start( program, arguments );
}

void mainfrm::f_find_out()
{
	QString mydir = QFileDialog::getExistingDirectory( this, tr("Choisissez un repertoire pour le diaporama"), "~", QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
        if ( mydir.isNull() )
        {
        }
	else
	{
		path_out_render->setText(mydir);
	}
}

void mainfrm::f_end_mainfrm(int valeur)
{
	// ****************************************
	// *** Point de sortie de l'application ***
	// ****************************************

	if ( mplayerProcess.state() == QProcess::Starting || mplayerProcess.state() == QProcess::Running )
	{
		mplayerProcess.kill();	
	}
	mplayerProcess.waitForFinished(1000);

	QString program = "rm";
       	QStringList arguments;
	arguments << "-rf";
	ispreview = 9;
       	arguments << QDir::homePath() + "/.TmpManSlide";
       	myprocess_9.start( program, arguments );
}

void mainfrm::f_ajout_effet()
{
	if ( comboeffets->count() < 40 )
	{
		contain_timeline->setDisabled(true);
		frame_toptimeline->setDisabled(true);
		frame_topmenu->setDisabled(true);
		frame_parameters->setDisabled(true);
		btgoextract->setDisabled(true);
		//
		QPixmap wl_pix_001(489,259);
		wl_pix_001.fill(Qt::black);
		QPixmap wl_pix_002 = QPixmap::grabWindow ( this->winId(), 255, 212, 489, 259);
		QPainter p;
		p.begin(&wl_pix_001);
		p.drawPixmap(0, 0, wl_pix_002, 0, 0, -1, -1 );
		p.drawPixmap(0, 0, gl_fond, 0, 0, -1, -1 );
		p.end();
		fond_extract->setPixmap(wl_pix_001);
		fond_extract->setGeometry(1,1,489,259);
		fond_extract->lower();
		//
		pathvideoextract->setText("");
		titreeffet->setText("");
		pbextract->setValue(0);
		frame_extract->setGeometry(254,211,491,261);
		frame_extract->show();
		frame_extract->raise();
	}
	else
	{
		QMessageBox::information(this, "Manslide", tr("Vous avez atteint le nombre maximum d'effet dans la bibliotheque. Supprimez en pour en ajouter de nouveaux."));
	}
}

void mainfrm::f_cancel_extract()
{
	contain_timeline->setEnabled(true);
	frame_toptimeline->setEnabled(true);
	frame_topmenu->setEnabled(true);
	frame_parameters->setEnabled(true);
	frame_extract->hide();
}

void mainfrm::f_find_video()
{
	QString wmyfic = QFileDialog::getOpenFileName(this, tr("Ouvrir une video"), "~", tr("Video (*.mpg *.MPG *.mpeg *.MPEG)"));
        if ( wmyfic.isNull() )
        {
        }
        else
        {
		pathvideoextract->setText(wmyfic);
		btgoextract->setEnabled(true);
	}
}

void mainfrm::f_go_extract()
{
	if ( titreeffet->text() != "" )
	{
		int idxsearch = 1;
		QString nomeffet = titreeffet->text();
		while ( nomeffet != pntmygl->table_effets[idxsearch][0] && idxsearch < 39 )
		{
			idxsearch = idxsearch + 1;
		}
		if ( idxsearch < 39 )
		{
			QMessageBox::information(this, "Manslide", tr("Il existe deja un effet avec le meme nom. Essayez avec un autre nom."));
		}
		else
		{
      			QFile myfic(wpathprojet + "/extract.sh");
		        if ( !myfic.open( QIODevice::WriteOnly ))
        		{
				QMessageBox::information(this, "Manslide", tr("Vous ne disposez pas des droits d ecriture dans ce dossier."));
				return;
			}
			else
			{
				ispreview = duree_extract->value() * 25;
				pbextract->setMaximum(ispreview);
				QString program = "bash";
				QStringList arguments;
				QTextStream out(&myfic);
				out << "#!/bin/bash" << endl;
				out << "mkdir -p " + wg_library + "/BIB_ManSlide/Effects/" + titreeffet->text() << endl;
				out << "cd " + wg_library + "/BIB_ManSlide/Effects/" + titreeffet->text() << endl;
				out << "mplayer -ao null -x 720 -y 576 -vo jpeg:quality=75 -frames " + QString::number(ispreview) + " \"" + pathvideoextract->text() + "\"" << endl;
				out << "rename 00 " + titreeffet->text() + " *.jpg" << endl;
				out << "exit" << endl;
				myfic.close();
				arguments << wpathprojet + "/extract.sh";
       				myprocess_8.start( program, arguments );
				frame_extract->setDisabled(true);
			}
		}
	}
	else
	{
		QMessageBox::information(this, "Manslide", tr("Vous devez choisir un nom pour votre effet."));
	}
}

void mainfrm::lecture_extract_video()
{
	QByteArray newData = myprocess_8.readAllStandardOutput();
	QString wl_var_1 = QString::fromLocal8Bit(newData);
       	int j = wl_var_1.indexOf("A:", 0);
        if ( j != -1 )
        {
		poursuite = poursuite + 1;
		pbextract->setValue(poursuite);
        }
}

void mainfrm::end_extract_video(int, QProcess::ExitStatus)
{
	frame_extract->setEnabled(true);
	contain_timeline->setEnabled(true);
	frame_toptimeline->setEnabled(true);
	frame_topmenu->setEnabled(true);
	frame_parameters->setEnabled(true);
	frame_extract->hide();
	//
	QString nomeffet = titreeffet->text();
	comboeffets->clear();
	comboeffets->insertItem(0,tr("Aucun"));
	QDir wcurrentDir(wg_library + "/BIB_ManSlide/Effects/");
	QStringList filters;
	filters << "*.*";
	int positem = 1;
	QDir subdir;

	foreach (QString file, wcurrentDir.entryList(QDir::Dirs | QDir::NoDotAndDotDot))
	{
		comboeffets->insertItem(positem, file);
		subdir.setPath(wg_library + "/BIB_ManSlide/Effects/" + file);
		pntmygl->table_effets[positem][0] = file;
		pntmygl->table_effets[positem][1] = QString::number(subdir.count());
		positem = positem + 1;
	}
	//
	int idxsearch = 1;
	
	while ( nomeffet != pntmygl->table_effets[idxsearch][0] && idxsearch < 39 )
	{
		idxsearch = idxsearch + 1;
	}
	if ( idxsearch < 39 )
	{
		comboeffets->setCurrentIndex(idxsearch);
		pntmygl->iseffect = idxsearch;
		table_photos[current_diapo][22] = nomeffet;
		pntmygl->load_effet(idxsearch,nomeffet);
	}
	else
	{
		QMessageBox::information(this, "Manslide", tr("L extraction a echouee pour une raison inconnue. Avez vous mplayer correctement installe ?"));
	}
}

void mainfrm::sl_go_start()
{
	position_flux = 0;
	pntmygl->wg_percent = table_photos[current_diapo][25].toFloat() / 100;
	pntmygl->sl_go_start();
	if ( table_photos[current_diapo][14] == "1" )
	{
		pntmygl->sl_opacity(table_photos[current_diapo][15].toInt());
	}
	pntmygl->updateGL();
}

void mainfrm::sl_go_end()
{
	position_flux = 1;
	pntmygl->wg_percent = table_photos[current_diapo][26].toFloat() / 100;
	pntmygl->sl_go_end();
	if ( table_photos[current_diapo][14] == "1" )
	{
		pntmygl->sl_opacity(table_photos[current_diapo][28].toInt());
	}
	pntmygl->updateGL();
}

void mainfrm::f_start_new()
{
	int destruct_i_1 = 0;
	while ( destruct_i_1 <= nbre_photos && destruct_i_1 < 400 )
	{
		delete table_pnt_img[destruct_i_1];
		table_color_fog[destruct_i_1] = QColor(128,128,128);
		destruct_i_1 = destruct_i_1 + 1;
	}
	QDir wcurrentDir(wpathprojet);
	QStringList filters;
	filters << "*.*";
	QString wl_tmp_1;

	foreach (QString file, wcurrentDir.entryList(QDir::Files))
	{
		wl_tmp_1 = wpathprojet + "/" + file;
		if ( QFile::remove ( wl_tmp_1 ) == false )
		{
			qDebug() << "ERROR REMOVING FILE FROM TMP DIRECTORY ...";
		}
	}
	lcdlength->display(0);
	pntmygl->initializeGL();
	pntmygl->sl_charge_image(QApplication::applicationDirPath() + "$N$U$L$L",QApplication::applicationDirPath() + "$N$U$L$L");
	pntmygl->updateGL();
	pntmygl->txt_sur_image = "";
	pntmygl->tool = 0;
	pntmygl->effet_titre = 0;
	pntmygl->x_titre = -1.8;
	pntmygl->v_titre = 1;
	frame_ed3d->setDisabled(true);
	path_photos_import = "~";
	pntmygl->mycolor.setRgb(255,255,255);
	zik_number = 0;
	titre_audio->setText("");
	zik_1->hide();
	total_audio = 0;
	must_redraw = 0;
	stick_menu->setGeometry(10,7,98,32);
	M_BT_PROJ->setDisabled(true);
	M_BT_PROJ->raise();
	group_support->setDisabled(true);
	frame_toptimeline->setDisabled(true);
	contain_timeline->setDisabled(true);
	frame_fade->setDisabled(true);
	img_selection->hide();
	bt_img_effects->setDisabled(true);
	bt_start_new->setDisabled(true);
	bt_fond->setDisabled(true);
	bt_screenshot->setDisabled(true);
	bt_supp_zik->setDisabled(true);
	param_diapo->setDisabled(true);
	bt_save_proj->setDisabled(true);
	bt_supprime_diapo->setDisabled(true);
	bt_param_import->setEnabled(true);
	bt_copy_all->setDisabled(true);
	bt_paste_all->setDisabled(true);
	bt_sync->setDisabled(true);
	bt_play->setDisabled(true);
	bt_play_all->setDisabled(true);
	bt_stop->setDisabled(true);
	bt_start->setDisabled(true);
	bt_end->setDisabled(true);
	M_BT_PROJ->setEnabled(true);
	M_BT_IMG->setEnabled(true);
	M_BT_PARAM->setDisabled(true);
	M_BT_EXPORT->setDisabled(true);
	M_BT_ZIK->setDisabled(true);
	M_BT_3D->setDisabled(true);
	nbre_photos = -1;
	current_diapo = -1;
}

void mainfrm::f_change_color_fog()
{
        table_color_fog[current_diapo] = QColorDialog::getColor(table_color_fog[current_diapo], this);
        if (table_color_fog[current_diapo].isValid())
	{
		pntmygl->fogcolor[0] = (float)table_color_fog[current_diapo].red() / (float)255;
		pntmygl->fogcolor[1] = (float)table_color_fog[current_diapo].green() / (float)255;
		pntmygl->fogcolor[2] = (float)table_color_fog[current_diapo].blue() / (float)255;
		pntmygl->fogcolor[3] = 0.5;
		if ( table_photos[current_diapo][14] == "1" )
		{
			pntmygl->change_fog_color();
			pntmygl->updateGL();
		}
        }
}

void mainfrm::f_changedur_2(int valeur)
{
	spindurtrans_2->setMaximum(valeur);
}

void mainfrm::f_supp_comment()
{
	title_comment->setText("");
	table_photos[current_diapo][24] = "";
	//
	QLabel *mylabel;
	mylabel = table_pnt_img[current_diapo];
	QImage wl_pix_1(wpathprojet + "/" + table_photos[current_diapo][0]);
	QPixmap wl_pix_2(wg_diapositive);
	QImage wl_pix_3;
	if ( wl_pix_1.height() > wl_pix_1.width() )
	{
		wl_pix_3 = wl_pix_1.scaledToHeight ( 63, Qt::FastTransformation );
	}
	else
	{
		wl_pix_3 = wl_pix_1.scaledToWidth ( 83, Qt::FastTransformation );
	}
	QPainter p;
	p.begin(&wl_pix_2);
	p.drawImage(7 + ((83 - wl_pix_3.width()) / 2), 7 + ((63 - wl_pix_3.height()) / 2), wl_pix_3, 0, 0, 83, 63 );
	QIcon myicon = lst_transitions->itemIcon(lst_transitions->currentIndex());
	myicon.paint ( &p, 56, 45, 32, 24, Qt::AlignCenter, QIcon::Normal, QIcon::On );
	p.end();
	mylabel->setPixmap(wl_pix_2);
}

void mainfrm::f_model_changed(int mymodel)
{
	if ( mymodel > 0 )
	{
		pntmygl->debut_px = table_models[mymodel - 1][0];
		pntmygl->debut_py = table_models[mymodel - 1][1];
		pntmygl->debut_pz = table_models[mymodel - 1][2];
		pntmygl->debut_rx = table_models[mymodel - 1][3];
		pntmygl->debut_ry = table_models[mymodel - 1][4];
		pntmygl->debut_rz = table_models[mymodel - 1][5];
		//
		pntmygl->fin_px = table_models[mymodel - 1][6];
		pntmygl->fin_py = table_models[mymodel - 1][7];
		pntmygl->fin_pz = table_models[mymodel - 1][8];
		pntmygl->fin_rx = table_models[mymodel - 1][9];
		pntmygl->fin_ry = table_models[mymodel - 1][10];
		pntmygl->fin_rz = table_models[mymodel - 1][11];
	}
}

void mainfrm::f_aff_modele()
{
	//
	QPixmap wl_pix_001(419,239);
	wl_pix_001.fill(Qt::black);
	QPixmap wl_pix_002 = QPixmap::grabWindow ( this->winId(), 9, 151, 419, 239);
	QPainter p;
	p.begin(&wl_pix_001);
	p.drawPixmap(0, 0, wl_pix_002, 0, 0, -1, -1 );
	p.drawPixmap(0, 0, gl_fond, 0, 0, -1, -1 );
	p.end();
	fond_effet->setPixmap(wl_pix_001);
	fond_effet->setGeometry(1,1,419,239);
	fond_effet->lower();
	//
	list_effets_anim->setCurrentIndex(0);
	bt_play->setDisabled(true);
	bt_play_all->setDisabled(true);
	bt_start->setDisabled(true);
	bt_end->setDisabled(true);
	frame_toptimeline->setDisabled(true);
	//
	frame_topmenu->setDisabled(true);
	frame_telecomm->setDisabled(true);
	contain_timeline->setDisabled(true);
	//
	frame_effet_anim->setGeometry(8,150,421,241);
	frame_effet_anim->show();
	frame_effet_anim->raise();
}

void mainfrm::f_close_modele()
{
	pntmygl->sl_stop();
	affichage_diapo();
	//
	bt_play->setEnabled(true);
	bt_play_all->setEnabled(true);
	bt_start->setEnabled(true);
	bt_end->setEnabled(true);
	frame_toptimeline->setEnabled(true);
	//
	frame_topmenu->setEnabled(true);
	frame_telecomm->setEnabled(true);
	contain_timeline->setEnabled(true);
	//
	frame_effet_anim->hide();
}

void mainfrm::f_valide_modele()
{
	pntmygl->sl_stop();
	//
	if ( list_effets_anim->currentIndex() > 0 )
	{
       		table_photos[current_diapo][1] = QString::number(table_models[list_effets_anim->currentIndex()-1][0]);
       		table_photos[current_diapo][2] = QString::number(table_models[list_effets_anim->currentIndex()-1][1]);
       		table_photos[current_diapo][3] = QString::number(table_models[list_effets_anim->currentIndex()-1][2]);
       		table_photos[current_diapo][4] = QString::number(table_models[list_effets_anim->currentIndex()-1][3]);
       		table_photos[current_diapo][5] = QString::number(table_models[list_effets_anim->currentIndex()-1][4]);
       		table_photos[current_diapo][6] = QString::number(table_models[list_effets_anim->currentIndex()-1][5]);
		//
       		table_photos[current_diapo][7] = QString::number(table_models[list_effets_anim->currentIndex()-1][6]);
       		table_photos[current_diapo][8] = QString::number(table_models[list_effets_anim->currentIndex()-1][7]);
       		table_photos[current_diapo][9] = QString::number(table_models[list_effets_anim->currentIndex()-1][8]);
       		table_photos[current_diapo][10] = QString::number(table_models[list_effets_anim->currentIndex()-1][9]);
       		table_photos[current_diapo][11] = QString::number(table_models[list_effets_anim->currentIndex()-1][10]);
       		table_photos[current_diapo][12] = QString::number(table_models[list_effets_anim->currentIndex()-1][11]);
		pntmygl->updateGL();
	}
	else
	{
       		pntmygl->debut_px = table_photos[current_diapo][0].toFloat();
       		pntmygl->debut_py = table_photos[current_diapo][1].toFloat();
       		pntmygl->debut_pz = table_photos[current_diapo][2].toFloat();
       		pntmygl->debut_rx = table_photos[current_diapo][3].toFloat();
       		pntmygl->debut_ry = table_photos[current_diapo][4].toFloat();
       		pntmygl->debut_rz = table_photos[current_diapo][5].toFloat();
		//
       		pntmygl->fin_px = table_photos[current_diapo][6].toFloat();
       		pntmygl->fin_px = table_photos[current_diapo][7].toFloat();
       		pntmygl->fin_px = table_photos[current_diapo][8].toFloat();
       		pntmygl->fin_px = table_photos[current_diapo][9].toFloat();
       		pntmygl->fin_px = table_photos[current_diapo][10].toFloat();
       		pntmygl->fin_px = table_photos[current_diapo][11].toFloat();
		//
		pntmygl->deplacementX = pntmygl->debut_px;
		pntmygl->deplacementY = pntmygl->debut_py;
		pntmygl->zoom = pntmygl->debut_pz;
		pntmygl->rotationX = pntmygl->debut_rx;
		pntmygl->rotationY = pntmygl->debut_ry;
		pntmygl->rotationZ = pntmygl->debut_rz;
		pntmygl->updateGL();
	}
	//
	bt_play->setEnabled(true);
	bt_play_all->setEnabled(true);
	bt_start->setEnabled(true);
	bt_end->setEnabled(true);
	frame_toptimeline->setEnabled(true);
	//
	frame_topmenu->setEnabled(true);
	frame_telecomm->setEnabled(true);
	contain_timeline->setEnabled(true);
	//
	affichage_diapo();
	frame_effet_anim->hide();
}

void mainfrm::f_preview()
{
	ispreview = 1;
	this->setDisabled(true);
	frame_ed3d->setGeometry(130,44,740,596);
	pntmygl->setGeometry(10,10,720,576);
	frame_ed3d->raise();
	QTimer::singleShot(150, this, SLOT(f_render()));
}

void mainfrm::f_save_param_manslide()
{
	if ( path_library->text() != "" )
	{
		QDir currentDir = QDir::homePath();
		QFile configfile( currentDir.path() + "/.manslide.cnf" );
		if (configfile.open(QIODevice::WriteOnly)) 
		{
			QTextStream out(&configfile);
			out << "R6" << endl;
			out << cblangue->currentText() << endl;
			out << QString::number(cpunumber->value() + 1) << endl;
			out << path_library->text() << endl;
			configfile.close();
			if ( cblangue->currentText() == "Francais" )
			{
				QMessageBox::information(this, "Manslide", "L'application va se fermer. Relancez la pour prendre en compte vos parametres.");
			}
			else
			{
				QMessageBox::information(this, "Manslide", "Application will be close. Please restart for apply your parameters.");
			}
			// *** Creation de la bibliotheque ***
			QDir tmpdir(path_library->text());
			if ( tmpdir.exists() == true )
			{
				QString program = "cp";
				QStringList arguments;
				ispreview = 4;
				arguments << "-r";
				arguments << "-f";
				arguments << QApplication::applicationDirPath() + "/BIB_ManSlide/";
				arguments << path_library->text();
				myprocess_9.start( program, arguments );
			}
			else
			{
				QMessageBox::information(this, "Manslide", tr("Le dossier n'existe pas ou plus ... ") + path_library->text());
			}
		}
		else
		{
			QMessageBox::information(this, "Manslide", tr("Impossible de creer le fichier de configuration. Disposez vous des droits d'ecriture dans ce dossier ...") + currentDir.dirName());
			this->close();
		}
	}
	else
	{
		QMessageBox::information(this, "Manslide", tr("Vous devez choisir le dossier qui contiendra les effets video. Assurez vous d'avoir les droits d'ecriture dans ce dossier."));
	}
}

void mainfrm::f_aff_m_proj()
{
	stick_menu->setGeometry(10,7,98,32);
	M_BT_PROJ->setDisabled(true);
	M_BT_PROJ->raise();
	M_BT_IMG->setEnabled(true);
	M_BT_PARAM->setEnabled(true);
	M_BT_EXPORT->setEnabled(true);
	M_BT_ZIK->setEnabled(true);
	M_BT_3D->setEnabled(true);
	if ( nbre_photos > 0 )
	{
		frame_toptimeline->setEnabled(true);
	}
	curframe->hide();
	curframe = menu_projet;
	menu_projet->show();
}

void mainfrm::f_aff_m_img()
{
	stick_menu->setGeometry(106,7,98,32);
	M_BT_PROJ->setEnabled(true);
	M_BT_IMG->setDisabled(true);
	M_BT_IMG->raise();
	M_BT_PARAM->setEnabled(true);
	M_BT_EXPORT->setEnabled(true);
	M_BT_ZIK->setEnabled(true);
	M_BT_3D->setEnabled(true);
	if ( nbre_photos >= 0 )
	{
		frame_toptimeline->setEnabled(true);
	}
	curframe->hide();
	curframe = menu_images;
	menu_images->setGeometry(0,50,411,471);
	menu_images->show();
}

void mainfrm::f_aff_m_param()
{
    	if ( nbre_photos >= 0 )
    	{
		stick_menu->setGeometry(206,7,98,32);
		M_BT_PROJ->setEnabled(true);
		M_BT_IMG->setEnabled(true);
		M_BT_PARAM->setDisabled(true);
		M_BT_PARAM->raise();
		M_BT_EXPORT->setEnabled(true);
		M_BT_ZIK->setEnabled(true);
		M_BT_3D->setEnabled(true);
		frame_toptimeline->setEnabled(true);
		curframe->hide();
		curframe = frame_parameters;
		frame_parameters->show();
	}
	lst_transitions->setFocus();
}

void mainfrm::f_aff_m_export()
{
    	if ( nbre_photos >= 0 )
    	{
		stick_menu->setGeometry(895,7,98,32);
		M_BT_PROJ->setEnabled(true);
		M_BT_IMG->setEnabled(true);
		M_BT_PARAM->setEnabled(true);
		M_BT_EXPORT->setDisabled(true);
		M_BT_ZIK->setEnabled(true);
		M_BT_3D->setEnabled(true);
		M_BT_EXPORT->raise();
		from_encoding->setMaximum(nbre_photos + 1);
		from_encoding->setMinimum(1);
		to_encoding->setMaximum(nbre_photos + 1);
		to_encoding->setValue(nbre_photos + 1);
		to_encoding->setMinimum(1);
		curframe->hide();
		curframe = param_encoding;
		frame_toptimeline->setDisabled(true);
		param_encoding->show();
	}
	from_encoding->setFocus();
}

void mainfrm::f_aff_m_zik()
{
    	if ( nbre_photos >= 0 )
    	{
		stick_menu->setGeometry(305,7,98,32);
		M_BT_PROJ->setEnabled(true);
		M_BT_IMG->setEnabled(true);
		M_BT_PARAM->setEnabled(true);
		M_BT_EXPORT->setEnabled(true);
		M_BT_3D->setEnabled(true);
		M_BT_ZIK->setDisabled(true);
		M_BT_ZIK->raise();
		frame_toptimeline->setEnabled(true);
		curframe->hide();
		curframe = frame_zik;
		frame_zik->show();
	}
	lst_transitions->setFocus();
}

void mainfrm::f_aff_m_3d()
{
    	if ( nbre_photos >= 0 )
    	{
		stick_menu->setGeometry(405,7,98,32);
		M_BT_PROJ->setEnabled(true);
		M_BT_IMG->setEnabled(true);
		M_BT_PARAM->setEnabled(true);
		M_BT_EXPORT->setEnabled(true);
		M_BT_ZIK->setEnabled(true);
		M_BT_3D->setDisabled(true);
		M_BT_3D->raise();
		frame_toptimeline->setEnabled(true);
		curframe->hide();
		curframe = frame_telecomm;
		frame_telecomm->show();
	}
	lst_transitions->setFocus();
}

void mainfrm::f_open_comment()
{
	QString wmyfic = QFileDialog::getOpenFileName(this, tr("Ouvrir un fichier audio"), "~", tr("Audio (*.ogg *.OGG)"));
        if ( wmyfic.isNull() )
        {
        }
        else
        {
		int tmpvar2 = wmyfic.lastIndexOf("/");
		QFile::copy ( wmyfic, wpathprojet + "/" + wmyfic.mid(tmpvar2 + 1,wmyfic.length() - (tmpvar2+1)) );
		title_comment->setText(wmyfic);
		table_photos[current_diapo][24] = wmyfic.mid(tmpvar2 + 1,wmyfic.length() - (tmpvar2+1));
		//
		QLabel *mylabel;
		mylabel = table_pnt_img[current_diapo];
		QImage wl_pix_1(wpathprojet + "/" + table_photos[current_diapo][0]);
		QPixmap wl_pix_2(wg_diapositive);
		QImage wl_pix_3;
		if ( wl_pix_1.height() > wl_pix_1.width() )
		{
			wl_pix_3 = wl_pix_1.scaledToHeight ( 63, Qt::FastTransformation );
		}
		else
		{
			wl_pix_3 = wl_pix_1.scaledToWidth ( 83, Qt::FastTransformation );
		}
		QPainter p;
		p.begin(&wl_pix_2);
		p.drawImage(7 + ((83 - wl_pix_3.width()) / 2), 7 + ((63 - wl_pix_3.height()) / 2), wl_pix_3, 0, 0, 83, 63 );
		p.drawPixmap(2, 57, wg_comment, 0, 0, -1, -1 );
		QIcon myicon = lst_transitions->itemIcon(lst_transitions->currentIndex());
		myicon.paint ( &p, 56, 45, 32, 24, Qt::AlignCenter, QIcon::Normal, QIcon::On );
		p.end();
		mylabel->setPixmap(wl_pix_2);
	}
}

void mainfrm::f_close_effets()
{
	frame_effets->hide();
	bt_play->setEnabled(true);
	bt_play_all->setEnabled(true);
	bt_start->setEnabled(true);
	bt_end->setEnabled(true);
	frame_toptimeline->setEnabled(true);
	//
	frame_topmenu->setEnabled(true);
	menu_images->setEnabled(true);
	contain_timeline->setEnabled(true);
}

void mainfrm::f_aff_effects()
{
	bt_play->setDisabled(true);
	bt_play_all->setDisabled(true);
	bt_start->setDisabled(true);
	bt_end->setDisabled(true);
	frame_toptimeline->setDisabled(true);
	//
	frame_topmenu->setDisabled(true);
	menu_images->setDisabled(true);
	contain_timeline->setDisabled(true);
	//
	frame_effets->setGeometry(219,165,562,351);
	frame_effets->show();
	frame_effets->raise();
}

void mainfrm::f_save_proj()
{
	QString wmyfic = QFileDialog::getSaveFileName(this, tr("Sauvegarder votre projet"), "~", tr("Projet (*.msz *.MSZ)"));
        if ( wmyfic.isNull() )
        {
        }
        else
        {
		if ( wmyfic.right(4) != ".msz" && wmyfic.right(4) != ".MSZ" )
		{
			wmyfic = wmyfic + ".msz";
		}
        	QFile myfic(wpathprojet + "/projet.gib");

        	if ( !myfic.open( QIODevice::WriteOnly ))
        	{
			QMessageBox::information(this, "Manslide", tr("Erreur lors de la sauvegarde du projet"));
			return;
		}
		else
		{
			QTextStream out(&myfic);
			int i = 0;
			int n = 0;
			ispreview = 1;
			//
			out << "V7" << endl;
			out << pntmygl->mycolor.red() << endl;
			out << pntmygl->mycolor.green() << endl;
			out << pntmygl->mycolor.blue() << endl;
			out << pntmygl->myfont.toString() << endl;
			out << "AUDIO:" << table_zik[0][0] << endl;
			out << "AUDIOLENGTH:" << table_zik[0][1] << endl;
			if ( loopsound->isChecked() == true )
			{
				out << "1" << endl;
			}
			else
			{
				out << "0" << endl;
			}
			//
			while ( i <= nbre_photos )
			{
				n = 0;
				while ( n < 33 )
				{
					out << table_photos[i][n] << endl;
					n = n + 1;
				}
				out << table_color_fog[i].red() << endl;
				out << table_color_fog[i].green() << endl;
				out << table_color_fog[i].blue() << endl;
				i = i + 1;
			}
			myfic.close();
        		QFile myfic2(QDir::homePath() + "/save.sh");

        		if ( !myfic2.open( QIODevice::WriteOnly ))
        		{
				QMessageBox::information(this, "Manslide", tr("Erreur lors de la sauvegarde du projet"));
				return;
			}
			else
			{
				QTextStream out2(&myfic2);
				//
				out2 << "#!/bin/bash" << endl;
				out2 << "cd " << QDir::homePath() << endl;
				out2 << "tar -cf " << wmyfic << " .TmpManSlide" << endl;
				out2 << "rm -f save.sh" << endl;
				myfic2.close();
				QString program = "bash";
       				QStringList arguments;
       				arguments << QDir::homePath() + "/save.sh";
       				myprocess_9.start( program, arguments );
			}
		}
	}
}

void mainfrm::end_save_project(int, QProcess::ExitStatus)
{
	if ( ispreview == 1 )
	{
		QMessageBox::information(this, "Manslide", tr("Sauvegarde du projet terminee."));
	}
	else
	{
		if ( ispreview == 0 )
		{
			int destruct_i_1 = 0;
			while ( destruct_i_1 <= nbre_photos && destruct_i_1 < 400 )
			{
				delete table_pnt_img[destruct_i_1];
				table_color_fog[destruct_i_1] = QColor(128,128,128);
				destruct_i_1 = destruct_i_1 + 1;
			}
        		QFile myfic(wpathprojet + "/projet.gib");
			QByteArray newData;
			QString wl_var_1;
			int tmp_num_001;
			zik_number = 0;
			zik_1->hide();
        		if ( !myfic.open( QIODevice::ReadOnly ))
        		{
				QMessageBox::information(this, "Manslide", tr("Erreur lors de l'ouverture du projet"));
				return;
			}
			else
			{
				newData = myfic.readLine(0);
				wl_var_1 = QString::fromLocal8Bit(newData);
				int nbreoccur = 33;
				newData = myfic.readLine(0);
				wl_var_1 = QString::fromLocal8Bit(newData);

				// *** Rouge ***
				tmp_num_001 = wl_var_1.mid(0, newData.count() - 1).toInt();
				pntmygl->mycolor.setRed( tmp_num_001 );
			
				// *** Vert ***
				newData = myfic.readLine(0);
				wl_var_1 = QString::fromLocal8Bit(newData);
				tmp_num_001 = wl_var_1.mid(0, newData.count() - 1).toInt();
				pntmygl->mycolor.setGreen( tmp_num_001 );

				// *** Bleu ***
				newData = myfic.readLine(0);
				wl_var_1 = QString::fromLocal8Bit(newData);
				tmp_num_001 = wl_var_1.mid(0, newData.count() - 1).toInt();
				pntmygl->mycolor.setBlue( tmp_num_001 );

				// *** Police ***
				newData = myfic.readLine(0);
				wl_var_1 = QString::fromLocal8Bit(newData);
				pntmygl->myfont.fromString(wl_var_1);

				// *** Musique pathname ***
				newData = myfic.readLine(0);
				wl_var_1 = QString::fromLocal8Bit(newData);
				if ( wl_var_1.length() > 7 )
				{
					table_zik[0][0] = wl_var_1.mid(6,wl_var_1.length() - 7);
					zik_number = 1;
				}

				// *** Musique duree ***
				newData = myfic.readLine(0);
				wl_var_1 = QString::fromLocal8Bit(newData);
				if ( wl_var_1.length() > 12 )
				{
					table_zik[0][1] = wl_var_1.mid(12,wl_var_1.length() - 13);
				}

				newData = myfic.readLine(0);
				wl_var_1 = QString::fromLocal8Bit(newData);
				if ( wl_var_1.mid(0,1) == "1" )
				{
					loopsound->setChecked(true);
				}
				else
				{
					loopsound->setChecked(false);
				}

				// *** Photos ***
				int i = 0;
				int j = 0;
				QImage wl_pix_1;
				QPixmap wl_pix_2(97,77);
				QImage wl_pix_3;
				QPainter p;
				QIcon myicon;
				QColor wl_mycolor;

				newData = myfic.readLine(0);
				while ( myfic.atEnd() == false )
				{
					j = 0;
					while ( j < nbreoccur )
					{
						wl_var_1 = QString::fromLocal8Bit(newData);
						table_photos[i][j] = wl_var_1.mid(0,wl_var_1.length() - 1);
						j = j + 1;
						newData = myfic.readLine(0);
					}
					// *** Rouge ***
					wl_var_1 = QString::fromLocal8Bit(newData);
					tmp_num_001 = wl_var_1.mid(0, newData.count() - 1).toInt();
					wl_mycolor.setRed( tmp_num_001 );
			
					// *** Vert ***
					newData = myfic.readLine(0);
					wl_var_1 = QString::fromLocal8Bit(newData);
					tmp_num_001 = wl_var_1.mid(0, newData.count() - 1).toInt();
					wl_mycolor.setGreen( tmp_num_001 );

					// *** Bleu ***
					newData = myfic.readLine(0);
					wl_var_1 = QString::fromLocal8Bit(newData);
					tmp_num_001 = wl_var_1.mid(0, newData.count() - 1).toInt();
					wl_mycolor.setBlue( tmp_num_001 );
					table_color_fog[i] = wl_mycolor;
					newData = myfic.readLine(0);

					myicon = lst_transitions->itemIcon(table_photos[i][20].toInt());
					if ( wl_pix_1.load( wpathprojet + "/" + table_photos[i][0]) == true )
					{
						wl_pix_2 = wg_diapositive;
						if ( wl_pix_1.height() > wl_pix_1.width() )
						{
							wl_pix_3 = wl_pix_1.scaledToHeight ( 63, Qt::FastTransformation );
						}
						else
						{
							wl_pix_3 = wl_pix_1.scaledToWidth ( 83, Qt::FastTransformation );
						}
        					p.begin(&wl_pix_2);
						p.drawImage(7 + ((83 - wl_pix_3.width()) / 2), 7 + ((63 - wl_pix_3.height()) / 2), wl_pix_3, 0, 0, 83, 63 );
						myicon.paint ( &p, 56, 45, 32, 24, Qt::AlignCenter, QIcon::Normal, QIcon::On );
						if ( table_photos[i][24] != "" )
						{
							p.drawPixmap(2, 57, wg_comment, 0, 0, -1, -1 );
						}
						p.end();
						//
						img_selection->show();
        					QLabel *mylabel = new QLabel(timeline);
						mylabel->installEventFilter(this);
						table_pnt_img[i] = mylabel;
        					mylabel->setGeometry( ((i * 97) + (i * 10)), 0, 97, 77);
						img_selection->setGeometry( ((i * 97) + (i * 10)), 0, 97, 77);
						img_selection->raise();
        					mylabel->setPixmap ( wl_pix_2 );
        					mylabel->show();
						//
						i = i + 1;
					}
				}
				nbre_photos = i - 1;
				current_diapo = 0;
				//
				if ( ((nbre_photos + 1) * 110) - 740 > 0 )
				{
					scroll_timeline->setMaximum(((nbre_photos + 1) * 110) - 740);
				}
				if ( i > 0 )
				{
					bt_start_new->setEnabled(true);
					bt_save_proj->setEnabled(true);
					bt_supprime_diapo->setEnabled(true);
					frame_ed3d->setEnabled(true);
					bt_copy_all->setEnabled(true);
					bt_play->setEnabled(true);
					bt_play_all->setEnabled(true);
					bt_stop->setEnabled(true);
					bt_start->setEnabled(true);
					bt_end->setEnabled(true);
					param_diapo->setEnabled(true);
					bt_img_effects->setEnabled(true);
					bt_fond->setEnabled(true);
					bt_screenshot->setEnabled(true);
					frame_toptimeline->setEnabled(true);
					contain_timeline->setEnabled(true);
					affichage_diapo();
					f_calcul_son();
				}
				else
				{
					lcdlength->display(0);
				}
				if ( zik_number > 0 )
				{
					int duree = table_zik[0][1].toInt();
					total_audio = 0;
					total_audio = total_audio + duree;
					int tmpvar2 = table_zik[0][0].lastIndexOf("/");
					titre_audio->setText(table_zik[0][0].mid(tmpvar2 + 1,table_zik[0][0].length() - (tmpvar2+1)));
					lcddursound->display(duree);
					zik_1->setText(table_zik[0][0]);
					zik_1->show();
					f_calcul_son();
					//
					bt_add_zik->setDisabled(true);
					bt_supp_zik->setEnabled(true);
					bt_sync->setEnabled(true);
				}
				// *** Fin du traitement ***
				myfic.close();
			}
		}
		else
		{
			if ( ispreview == 2 )
			{
				this->setEnabled(true);
				QImage wl_pix_1;
				if ( wl_pix_1.load(wpathprojet + "/" + table_photos[current_diapo][0]) == true )
				{
					QLabel *mylabel;
					QIcon myicon = lst_transitions->itemIcon(lst_transitions->currentIndex());
					mylabel = table_pnt_img[current_diapo];
					QPixmap wl_pix_2(wg_diapositive);
					QImage wl_pix_3;
					if ( wl_pix_1.height() > wl_pix_1.width() )
					{
						wl_pix_3 = wl_pix_1.scaledToHeight ( 63, Qt::FastTransformation );
					}
					else
					{
						wl_pix_3 = wl_pix_1.scaledToWidth ( 83, Qt::FastTransformation );
					}
					QPainter p;
					p.begin(&wl_pix_2);
					p.drawImage(7 + ((83 - wl_pix_3.width()) / 2), 7 + ((63 - wl_pix_3.height()) / 2), wl_pix_3, 0, 0, 83, 63 );
					if ( table_photos[current_diapo][24] != "" )
					{
						p.drawPixmap(2, 57, wg_comment, 0, 0, -1, -1 );
					}
					myicon.paint ( &p, 56, 45, 32, 24, Qt::AlignCenter, QIcon::Normal, QIcon::On );
					p.end();
					mylabel->setPixmap(wl_pix_2);
					affichage_diapo();
				}
				else
				{
					QMessageBox::information(this, "Manslide", tr("Erreur recuperation image depuis The Gimp."));
				}
			}
			else
			{
				if ( ispreview == 4 )
				{
					this->close();
				}
				else
				{
					if ( ispreview == 5 )
					{
						comboeffets->clear();
						comboeffets->insertItem(0,tr("Aucun"));
						QDir wcurrentDir(wg_library + "/BIB_ManSlide/Effects/");
						QStringList filters;
						filters << "*.*";
						int positem = 1;
						QDir subdir;

						foreach (QString file, wcurrentDir.entryList(QDir::Dirs | QDir::NoDotAndDotDot))
						{
							comboeffets->insertItem(positem, file);
							subdir.setPath(wg_library + "/BIB_ManSlide/Effects/" + file);
							pntmygl->table_effets[positem][0] = file;
							pntmygl->table_effets[positem][1] = QString::number(subdir.count());
							positem = positem + 1;
						}
						comboeffets->setCurrentIndex(0);
						pntmygl->iseffect = 0;
						table_photos[current_diapo][22] = "";
						pntmygl->load_effet(0,"");
					}
					else
					{
						if ( ispreview == 6 )
						{
							this->setEnabled(true);
							frame_topmenu->setDisabled(true);
							contain_timeline->setDisabled(true);
							frame_toptimeline->setDisabled(true);
							menu_images->setDisabled(true);
							player_open_video(wpathprojet + "/stepTFI.avi");
						}
					}
				}
			}
		}
	}
}

void mainfrm::f_open_proj()
{
	QString wmyfic = QFileDialog::getOpenFileName(this, tr("Ouvrir un projet"), "~", tr("Projet (*.msz *.MSZ)"));
        if ( wmyfic.isNull() )
        {
        }
        else
        {
        	QFile myfic2(QDir::homePath() + "/open.sh");

        	if ( !myfic2.open( QIODevice::WriteOnly ))
        	{
			QMessageBox::information(this, "Manslide", tr("Erreur lors de l ouverture du projet"));
			return;
		}
		else
		{
			QTextStream out2(&myfic2);
			//
			ispreview = 0;
			out2 << "#!/bin/bash" << endl;
			out2 << "cd " << QDir::homePath() << endl;
			out2 << "tar -xf " << wmyfic << endl;
			out2 << "rm -f open.sh" << endl;
			myfic2.close();
			QString program = "bash";
       			QStringList arguments;
       			arguments << QDir::homePath() + "/open.sh";
       			myprocess_9.start( program, arguments );
		}
	}
}

void mainfrm::f_sync()
{
	this->setDisabled(true);
	int dur_by_slide = total_audio / (nbre_photos + 1);
	int dur_by_trans = 2;
	if ( dur_by_slide < 1 )
	{
		dur_by_slide = 1;
		dur_by_trans = 1;
	}
	int i = 0;
	while ( i <= nbre_photos )
	{
		if ( table_photos[i][20].toInt() > 0 )
		{
			table_photos[i][16] = QString::number(dur_by_slide);
			table_photos[i][21] = QString::number(dur_by_trans);
		}
		else
		{
			table_photos[i][16] = QString::number(dur_by_slide);
		}
		i = i + 1;
	}
	spindurtrans->setValue(table_photos[i][current_diapo].toInt());
	spindurdiapo->setValue(dur_by_slide);
	spindurpausefirst->setValue(0);
	spindurpauselast->setValue(0);
	f_calcul_son();
	this->setEnabled(true);
}

void mainfrm::f_raz()
{
	table_photos[current_diapo][1] = QString::number(0);
	table_photos[current_diapo][2] = QString::number(0);
	table_photos[current_diapo][3] = QString::number(-3.8);
	table_photos[current_diapo][4] = QString::number(0);
	table_photos[current_diapo][5] = QString::number(0);
	table_photos[current_diapo][6] = QString::number(0);
	//
	table_photos[current_diapo][7] = QString::number(0);
	table_photos[current_diapo][8] = QString::number(0);
	table_photos[current_diapo][9] = QString::number(-3.8);
	table_photos[current_diapo][10] = QString::number(0);
	table_photos[current_diapo][11] = QString::number(0);
	table_photos[current_diapo][12] = QString::number(0);
	//
	must_redraw = 0;
        affichage_diapo();
}

void mainfrm::f_copy()
{
	tmp_cpast[0] = table_photos[current_diapo][1];
	tmp_cpast[1] = table_photos[current_diapo][2];
	tmp_cpast[2] = table_photos[current_diapo][3];
	tmp_cpast[3] = table_photos[current_diapo][4];
	tmp_cpast[4] = table_photos[current_diapo][5];
	tmp_cpast[5] = table_photos[current_diapo][6];
	//
	tmp_cpast[6] = table_photos[current_diapo][7];
	tmp_cpast[7] = table_photos[current_diapo][8];
	tmp_cpast[8] = table_photos[current_diapo][9];
	tmp_cpast[9] = table_photos[current_diapo][10];
	tmp_cpast[10] = table_photos[current_diapo][11];
	tmp_cpast[11] = table_photos[current_diapo][12];
	//
	bt_paste_all->setEnabled(true);
}

void mainfrm::f_paste()
{
	table_photos[current_diapo][1] = tmp_cpast[0];
	table_photos[current_diapo][2] = tmp_cpast[1];
	table_photos[current_diapo][3] = tmp_cpast[2];
	table_photos[current_diapo][4] = tmp_cpast[3];
	table_photos[current_diapo][5] = tmp_cpast[4];
	table_photos[current_diapo][6] = tmp_cpast[5];
	//
	table_photos[current_diapo][7] = tmp_cpast[6];
	table_photos[current_diapo][8] = tmp_cpast[7];
	table_photos[current_diapo][9] = tmp_cpast[8];
	table_photos[current_diapo][10] = tmp_cpast[9];
	table_photos[current_diapo][11] = tmp_cpast[10];
	table_photos[current_diapo][12] = tmp_cpast[11];
	//
	must_redraw = 0;
        affichage_diapo();
}

void mainfrm::f_pos_leg(int valeur)
{
	table_photos[current_diapo][23] = QString::number(valeur);
	pntmygl->effet_titre = valeur;
	pntmygl->x_titre = -1.8;
	pntmygl->y_titre = 20;
	pntmygl->updateGL();
}

void mainfrm::f_couleur()
{
        pntmygl->mycolor = QColorDialog::getColor(pntmygl->mycolor, this);
        if (pntmygl->mycolor.isValid())
	{
		pntmygl->updateGL();
        }
}

void mainfrm::f_police()
{
	bool ok;
	pntmygl->myfont = QFontDialog::getFont(&ok, pntmygl->myfont, this);
    	if (ok) 
	{
		pntmygl->updateGL();
	}
}

void mainfrm::f_chg_leg(QString saitxt)
{
	table_photos[current_diapo][17] = saitxt;
	pntmygl->txt_sur_image = saitxt;
	pntmygl->updateGL();
}

void mainfrm::f_chg_tool_a()
{
	pntmygl->tool = 1;
}

void mainfrm::f_chg_tool_b()
{
	pntmygl->tool = 2;
}

void mainfrm::f_chg_tool_c()
{
	pntmygl->tool = 3;
}

void mainfrm::f_chg_tool_d()
{
	pntmygl->tool = 4;
}

void mainfrm::f_chg_tool_e()
{
	pntmygl->tool = 5;
}

void mainfrm::f_chg_tool_f()
{
	pntmygl->tool = 6;
}

void mainfrm::f_durp_deb(int valeur)
{
	table_photos[current_diapo][19] = QString::number(valeur);
	pntmygl->pause_debut = valeur;
	f_calcul_son();
}

void mainfrm::f_durp_end(int valeur)
{
	table_photos[current_diapo][18] = QString::number(valeur);
	pntmygl->pause_fin = valeur;
	f_calcul_son();
}

void mainfrm::f_factor(int valeur)
{
	table_photos[current_diapo][30] = QString::number(valeur);
	pntmygl->size_factor = valeur;
	pntmygl->updateGL();
}

void mainfrm::f_opacity(int valeur)
{
	table_photos[current_diapo][15] = QString::number(dial_opacity->value());
	if ( position_flux == 0 )
	{
		pntmygl->sl_opacity(valeur);
	}
}

void mainfrm::f_opacity_slide(int valeur)
{
	table_photos[current_diapo][32] = QString::number(dial_opacity_slide->value());
	pntmygl->wg_percent_slide = (float)(table_photos[current_diapo][32].toFloat() / 100);
	pntmygl->updateGL();
}

void mainfrm::f_opacity_2(int valeur)
{
	table_photos[current_diapo][28] = QString::number(dial_opacity_2->value());
	if ( position_flux == 1 )
	{
		pntmygl->sl_opacity(valeur);
	}
}

void mainfrm::f_percent_blending(int valeur)
{
	table_photos[current_diapo][25] = QString::number(dial_percent_blending->value());
	pntmygl->wg_percent = table_photos[current_diapo][25].toFloat() / 100;
	label_percent_1->setText( table_photos[current_diapo][25] + " %");
	if ( position_flux == 0 )
	{
		pntmygl->updateGL();
	}
}

void mainfrm::f_percent_blending_2(int valeur)
{
	table_photos[current_diapo][26] = QString::number(dial_percent_blending_2->value());
	pntmygl->wg_percent = table_photos[current_diapo][26].toFloat() / 100;
	label_percent_2->setText( table_photos[current_diapo][26] + " %");
	if ( position_flux == 1 )
	{
		pntmygl->updateGL();
	}
}

void mainfrm::f_brouillard(int valeur)
{
	if ( valeur == 0)
	{
		table_photos[current_diapo][14] = "0";
	}
	else
	{
		table_photos[current_diapo][14] = "1";
		pntmygl->change_fog_color();
	}
	pntmygl->sl_brouillard(valeur);
}

void mainfrm::f_backanim(int valeur)
{
	if ( valeur == 0)
	{
		table_photos[current_diapo][29] = "0";
		pntmygl->isbackanim = 0;
	}
	else
	{
		table_photos[current_diapo][29] = "1";
		pntmygl->isbackanim = 1;
	}
	pntmygl->updateGL();
}

void mainfrm::f_change_fond()
{
        /*QString myfic = QFileDialog::getOpenFileName(
                this,
                "Ouvrir un fichier",
                "~",
                "Images (*.jpg *.JPG *.jpeg *.JPEG *.png *.PNG)");*/
   	Preview* p = new Preview;
   	Q3FileDialog* fd = new Q3FileDialog(this);
   	fd->setContentsPreviewEnabled(true);
   	fd->setContentsPreview(p, p);
	fd->setMode(Q3FileDialog::ExistingFile);
	fd->setDir(path_photos_import);
	fd->setFilter("*.jpg *.JPG *.jpeg *.JPEG *.png *.PNG");
  	fd->setPreviewMode(Q3FileDialog::Contents);
	QString myfic;
	if (fd->exec() == QDialog::Accepted)
	{
		myfic = fd->selectedFile();
	}
        if ( myfic.isNull() )
        {
        }
        else
        {
		QPixmap wl_pix_1(myfic);
		QPixmap wl_pix_2(720,576);
		QPixmap wl_pix_3;
		wl_pix_2.fill(Qt::black);

		if ( wl_pix_1.width() > wl_pix_1.height() )
		{
			wl_pix_3 = wl_pix_1.scaledToWidth ( 720, Qt::FastTransformation );
		}
		else
		{
			wl_pix_3 = wl_pix_1.scaledToHeight ( 576, Qt::FastTransformation );
		}
		QPainter p;
        	p.begin(&wl_pix_2);
		p.drawPixmap(((720 - wl_pix_3.width()) / 2), ((576 - wl_pix_3.height()) / 2), wl_pix_3, 0, 0, -1, -1 );
		p.end();
            	int i = myfic.lastIndexOf( '/' );
            	if ( i != -1 )
            	{
                	outfilename = myfic.mid(i, myfic.length() - i);
			wl_pix_2.save(wpathprojet + "/" + outfilename + ".jpg","JPEG",75);
			//
			table_photos[current_diapo][13] = outfilename + ".jpg";
			pntmygl->sl_change_fond(wpathprojet + "/" + outfilename + ".jpg");
			pntmygl->updateGL();
		}
	}
}

void mainfrm::f_sup_zik()
{
	if ( QFile::remove ( wpathprojet + "/" + table_zik[0][0] ) == false )
	{
		qDebug() << "ERROR REMOVING FILE FROM TMP DIRECTORY ...";
	}
	zik_number = zik_number - 1;
	total_audio = 0;
	titre_audio->setText("");
	lcddursound->display(0);
	bt_supp_zik->setDisabled(true);
	frame_fade->setDisabled(true);
	bt_sync->setDisabled(true);
	bt_add_zik->setEnabled(true);
	zik_1->hide();
}

void mainfrm::f_add_zik()
{
	if ( zik_number < 1 )
	{
        	QString myfic = QFileDialog::getOpenFileName(
                	this,
                	tr("Ouvrir un fichier"),
                	path_photos_import,
                	"Musiques (*.OGG *.ogg)");
        	if ( myfic.isNull() )
        	{
        	}
        	else
        	{
			int tmpvar2 = myfic.lastIndexOf("/");
			QFile::copy ( myfic, wpathprojet + "/" + myfic.mid(tmpvar2 + 1,myfic.length() - (tmpvar2+1)) );
			table_zik[0][0] = myfic.mid(tmpvar2 + 1,myfic.length() - (tmpvar2+1));
			wglob_str_1 = "";
			QString program = "ogginfo";
       			QStringList arguments;
       			arguments << myfic;
       			myprocess_5.start( program, arguments );
		}
	}
	else
	{
		QMessageBox::information(this, "Manslide", tr("le nombre maximum de bandes son est de 1 pour l'instant. Desole ..."));
	}
}

void mainfrm::lecture_console_import_zik()
{
	QByteArray newData = myprocess_5.readAllStandardOutput();
	QString wl_var_1 = QString::fromLocal8Bit(newData);
	wglob_str_1 = wglob_str_1 + wl_var_1;
}

void mainfrm::end_zik_import(int, QProcess::ExitStatus)
{
	myprocess_5.terminate();
        int i = wglob_str_1.indexOf("Playback length:", 0);
        if ( i != -1 )
        {
		QString wl_str_1 = "0";
		QString wl_str_2 = "0";
		int bascule = 0;

		while ( wglob_str_1.mid(i + 17, 1) != "." )
		{
			if ( wglob_str_1.mid(i + 17, 1) != "m" )
			{
				if ( bascule == 0 )
				{
					wl_str_1 = wl_str_1 + wglob_str_1.mid(i + 17,1);
				}
				else
				{
					wl_str_2 = wl_str_2 + wglob_str_1.mid(i + 17,1);
				}
			}
			else
			{
				bascule = 1;
				i = i + 1;
			}
			i = i + 1;
		}
		int wz1 = wl_str_1.toInt() * 60;
		int wz2 = wl_str_2.toInt();
		int duree = wz1 + wz2;

		total_audio = 0;
		total_audio = total_audio + duree;

		titre_audio->setText(table_zik[zik_number][0]);
		lcddursound->display(duree);
		zik_1->setText(table_zik[0][0]);
		zik_1->show();
		table_zik[0][1] = QString::number(duree);
		frame_fade->setEnabled(true);
		bt_sync->setEnabled(true);
		bt_supp_zik->setEnabled(true);
		zik_number = zik_number + 1;
		bt_add_zik->setDisabled(true);
		f_calcul_son();
        }
}

void mainfrm::f_calcul_son()
{
	int j=0;
	int cumul_diapo = 0;
	int total_diapo = 0;
	int duree = table_zik[0][1].toInt();
	while ( j <= nbre_photos )
	{
		total_diapo = total_diapo + ( table_photos[j][16].toInt() + table_photos[j][18].toInt() + table_photos[j][19].toInt() );
		j = j + 1;
	}
	lcdlength->display(total_diapo);
	if ( zik_number > 0 )
	{
		j = 0;
		while ( cumul_diapo < duree && j <= nbre_photos )
		{
			cumul_diapo = cumul_diapo + ( table_photos[j][16].toInt() + table_photos[j][18].toInt() + table_photos[j][19].toInt() );
			j = j + 1;
		}
		if ( duree > cumul_diapo )
		{
			zik_1->setGeometry(0,87,((j + 1) * 110),21);
		}
		else
		{
			if ( duree < cumul_diapo )
			{
				zik_1->setGeometry(0,87,(j * 110) - 50,21);
			}
			else
			{
				zik_1->setGeometry(0,87,(j * 110) - 10 ,21);
			}
		}
	}
}

void mainfrm::f_apply_effets(int state)
{
	if ( comboeffets->count() > 0 )
	{
		if (state == 0)
		{
			pntmygl->iseffect = 0;
			pntmygl->nameanim = "";
			table_photos[current_diapo][22] = "0";
			pntmygl->updateGL();
		}
		else
		{
			pntmygl->iseffect = state;
			pntmygl->maxanim = pntmygl->table_effets[state][1].toInt();
			table_photos[current_diapo][22] = comboeffets->currentText();
			pntmygl->load_effet(state,comboeffets->currentText());
			pntmygl->updateGL();
		}
	}
}

void mainfrm::f_bidon()
{
}

void mainfrm::f_screenshot()
{
	frame_ed3d->setGeometry(130,44,740,596);
	pntmygl->setGeometry(10,10,720,576);
	frame_ed3d->raise();
	QString s = QFileDialog::getSaveFileName(
        	this,
                tr("Nom de l'image enregistree"),
                path_photos_import,
                "Images (*.jpg)");
        if ( s.isNull() )
        {
        }
        else
	{
		if ( s.mid(s.length() - 4,4) != ".jpg" )
		{
			s = s + ".jpg";
		}
		QTimer::singleShot(1500, this, SLOT(f_bidon()));
		pntmygl->grabframe(s);				// <----- UTILISER COMME SOLUTION A UN BUG NE PAS ENLEVER
	}
	frame_ed3d->setGeometry(440,60,525,408);
	pntmygl->setGeometry(10,10,505,388);
}

void mainfrm::f_close_param_import()
{
	if ( nbre_photos >= 0 )
	{
		int result = QMessageBox::information(this, "Manslide", tr("Voulez vous appliquer ces nouveaux parametres a l ensemble des diapositives ?") , tr("Oui"), tr("Non"), 0, 1 );
		if (result == 0)
		{
			int wl_compteur = 0;
			int wl_random_value;
			must_redraw = 0;
			while ( wl_compteur <= nbre_photos )
			{
				current_diapo = wl_compteur;
				if ( lst_transitions_2->currentIndex() == 1 )
				{
					wl_random_value = rand()%(lst_transitions_2->count() - 1);
					if ( wl_random_value < 2 )
					{
						wl_random_value = 2;
					}
				}
				else
				{
					wl_random_value = lst_transitions_2->currentIndex() - 1;
				}
				table_photos[wl_compteur][16] = QString::number(spindurdiapo_2->value());
				table_photos[wl_compteur][21] = QString::number(spindurtrans_2->value());
				f_transition_changed(wl_random_value);
				wl_compteur = wl_compteur + 1;
			}
			f_calcul_son();
			affichage_diapo();
		}
	}
	frame_topmenu->setEnabled(true);
	contain_timeline->setEnabled(true);
	menu_projet->setEnabled(true);
	frame_zik->setEnabled(true);
	frame_telecomm->setEnabled(true);
	menu_images->setEnabled(true);
	frame_parameters->setEnabled(true);
	param_encoding->setEnabled(true);
	bt_start->setEnabled(true);
	bt_stop->setEnabled(true);
	bt_play->setEnabled(true);
	bt_play_all->setEnabled(true);
	bt_end->setEnabled(true);
	frame_parametres->hide();
}

void mainfrm::f_affiche_parametres()
{
	frame_topmenu->setDisabled(true);
	contain_timeline->setDisabled(true);
	menu_projet->setDisabled(true);
	frame_zik->setDisabled(true);
	frame_telecomm->setDisabled(true);
	menu_images->setDisabled(true);
	frame_parameters->setDisabled(true);
	param_encoding->setDisabled(true);
	bt_start->setDisabled(true);
	bt_stop->setDisabled(true);
	bt_play->setDisabled(true);
	bt_play_all->setDisabled(true);
	bt_end->setDisabled(true);
	frame_parametres->setGeometry(399,206,201,211);
	frame_parametres->show();
	frame_parametres->raise();
}

void mainfrm::f_changedur(int valeur)
{
	if ( nbre_photos >= 0 )
	{
		table_photos[current_diapo][16] = QString::number(valeur);
		pntmygl->wg_duree = valeur;
		spindurtrans->setMaximum(valeur);
		f_calcul_son();
	}
	else
	{
		pntmygl->wg_duree = 1;
		spindurdiapo->setValue(1);
	}
}


void mainfrm::supp_diapo()
{
	must_redraw = 0;
	// *** Recherche la présence d'autres occurences ***
	int wl_cpt_001 = 0;
	while ( wl_cpt_001 <= nbre_photos )
	{
		if ( table_photos[wl_cpt_001][0] == table_photos[current_diapo][0] && wl_cpt_001 != current_diapo )
		{
			wl_cpt_001 = 999;
		}
		wl_cpt_001 = wl_cpt_001 + 1;
	}
	if ( wl_cpt_001 < 999 )
	{
		if ( QFile::remove ( wpathprojet + "/" + table_photos[current_diapo][0] ) == false )
		{
			qDebug() << "ERROR REMOVING FILE FROM TMP DIRECTORY ...";
		}
	}

	if ( current_diapo == nbre_photos)
	{
		if ( nbre_photos > 0 )
		{
			delete table_pnt_img[current_diapo];
			current_diapo = current_diapo - 1;
			nbre_photos = nbre_photos - 1;
			affichage_diapo();
		}
		else
		{
			if ( nbre_photos == 0 )
			{
				delete table_pnt_img[current_diapo];
				current_diapo = current_diapo - 1;
				nbre_photos = nbre_photos - 1;
				QPixmap nullpix(791,571);
				QColor mycolor(0,0,0);
				nullpix.fill(mycolor);
				//
				bt_save_proj->setDisabled(true);
				bt_supprime_diapo->setDisabled(true);
				frame_ed3d->setDisabled(true);
				bt_play->setDisabled(true);
				bt_play_all->setDisabled(true);
				bt_stop->setDisabled(true);
				bt_start->setDisabled(true);
				bt_end->setDisabled(true);
				param_diapo->setDisabled(true);
				bt_img_effects->setDisabled(true);
				bt_fond->setDisabled(true);
				bt_screenshot->setDisabled(true);
				frame_toptimeline->setDisabled(true);
				bt_start_new->setDisabled(true);
				plane->setChecked(true);
				group_support->setDisabled(true);
				img_selection->hide();
				pntmygl->iseffect = 0;
				//
				pntmygl->sl_charge_image(QApplication::applicationDirPath() + "$N$U$L$L",QApplication::applicationDirPath() + "$N$U$L$L");
				pntmygl->updateGL();
				stick_menu->setGeometry(10,7,98,32);
				frame_effets->hide();
				M_BT_PROJ->raise();
				menu_projet->setGeometry(0,50,391,471);
				menu_projet->show();
				menu_images->hide();
				frame_telecomm->hide();
				frame_zik->hide();
				frame_parameters->hide();
				param_encoding->hide();
				menu_projet->setFocus();
				M_BT_IMG->setEnabled(true);
				M_BT_IMG->raise();
			}
		}
	}
	else
	{
		delete table_pnt_img[current_diapo];
		QLabel *mylabel;
		QPoint mypoint;
		int i = current_diapo;
		int j = nbre_photos;
		while (i < j)
		{
			table_photos[i][0] = table_photos[i+1][0];
			table_photos[i][1] = table_photos[i+1][1];
			table_photos[i][2] = table_photos[i+1][2];
			table_photos[i][3] = table_photos[i+1][3];
			table_photos[i][4] = table_photos[i+1][4];
			table_photos[i][5] = table_photos[i+1][5];
			table_photos[i][6] = table_photos[i+1][6];
			table_photos[i][7] = table_photos[i+1][7];
			table_photos[i][8] = table_photos[i+1][8];
			table_photos[i][9] = table_photos[i+1][9];
			table_photos[i][10] = table_photos[i+1][10];
			table_photos[i][11] = table_photos[i+1][11];
			table_photos[i][12] = table_photos[i+1][12];
			table_photos[i][13] = table_photos[i+1][13];
			table_photos[i][14] = table_photos[i+1][14];
			table_photos[i][15] = table_photos[i+1][15];
			table_photos[i][16] = table_photos[i+1][16];
			table_photos[i][17] = table_photos[i+1][17];
			table_photos[i][18] = table_photos[i+1][18];
			table_photos[i][19] = table_photos[i+1][19];
			table_photos[i][20] = table_photos[i+1][20];
			table_photos[i][21] = table_photos[i+1][21];
			table_photos[i][22] = table_photos[i+1][22];
			table_photos[i][23] = table_photos[i+1][23];
			table_photos[i][24] = table_photos[i+1][24];
			table_pnt_img[i] = table_pnt_img[i+1];
			mylabel = table_pnt_img[i];
			mypoint = mylabel->pos();
			mylabel->setGeometry( mypoint.x() - 107, 0 , 97, 77);
			i = i + 1;
		}
		if ( current_diapo > 0 )
		{
			current_diapo = current_diapo - 1;
		}
		nbre_photos = nbre_photos - 1;
		affichage_diapo();
	}
	f_calcul_son();
	if ( ((nbre_photos + 1) * 110) - 740 > 0 )
	{
		scroll_timeline->setMaximum(((nbre_photos + 1) * 110) - 740);
	}
	else
	{
		scroll_timeline->setMaximum(0);
	}
}

void mainfrm::md_start()
{
	table_photos[current_diapo][1] = QString::number(pntmygl->deplacementX);
	table_photos[current_diapo][2] = QString::number(pntmygl->deplacementY);
	table_photos[current_diapo][3] = QString::number(pntmygl->zoom);
	table_photos[current_diapo][4] = QString::number(pntmygl->rotationX);
	table_photos[current_diapo][5] = QString::number(pntmygl->rotationY);
	table_photos[current_diapo][6] = QString::number(pntmygl->rotationZ);
	table_photos[current_diapo][13] = pntmygl->path_fond;
	if ( check_fog->isChecked() == true )
	{
		table_photos[current_diapo][14] = "1";
		table_photos[current_diapo][15] = QString::number(dial_opacity->value());
		table_photos[current_diapo][28] = QString::number(dial_opacity_2->value());
	}
	else
	{
		table_photos[current_diapo][14] = "0";
		table_photos[current_diapo][15] = "30";
		table_photos[current_diapo][28] = "30";
	}
	table_photos[current_diapo][18] = QString::number(spindurpauselast->value());
	table_photos[current_diapo][19] = QString::number(spindurpausefirst->value());
	table_photos[current_diapo][22] = comboeffets->currentText();
	pntmygl->sl_mark_deb();
}

void mainfrm::md_fin()
{
	table_photos[current_diapo][7] = QString::number(pntmygl->deplacementX);
	table_photos[current_diapo][8] = QString::number(pntmygl->deplacementY);
	table_photos[current_diapo][9] = QString::number(pntmygl->zoom);
	table_photos[current_diapo][10] = QString::number(pntmygl->rotationX);
	table_photos[current_diapo][11] = QString::number(pntmygl->rotationY);
	table_photos[current_diapo][12] = QString::number(pntmygl->rotationZ);
	table_photos[current_diapo][13] = pntmygl->path_fond;
	if ( check_fog->isChecked() == true )
	{
		table_photos[current_diapo][14] = "1";
		table_photos[current_diapo][15] = QString::number(dial_opacity->value());
		table_photos[current_diapo][28] = QString::number(dial_opacity_2->value());
	}
	else
	{
		table_photos[current_diapo][14] = "0";
		table_photos[current_diapo][15] = "30";
		table_photos[current_diapo][28] = "30";
	}
	table_photos[current_diapo][18] = QString::number(spindurpauselast->value());
	table_photos[current_diapo][19] = QString::number(spindurpausefirst->value());
	table_photos[current_diapo][22] = comboeffets->currentText();
	pntmygl->sl_mark_fin();
}

void mainfrm::load_photo()
{
	if ( nbre_photos < 400 )
	{
        	/*QStringList listsfile = QFileDialog::getOpenFileNames(
                	this,
                	tr("Ouvrir un fichier"),
                	path_photos_import,
                	"Images (*.jpg *.JPG *.jpeg *.JPEG *.png *.PNG)");*/
   		Preview* p = new Preview;
   		Q3FileDialog* fd = new Q3FileDialog(this);
   		fd->setContentsPreviewEnabled(true);
   		fd->setContentsPreview(p, p);
		fd->setMode(Q3FileDialog::ExistingFiles);
		fd->setDir(path_photos_import);
		fd->setFilter("*.jpg *.JPG *.jpeg *.JPEG *.png *.PNG");
  		fd->setPreviewMode(Q3FileDialog::Contents);
		QStringList listsfile;
		if (fd->exec() == QDialog::Accepted)
		{
			listsfile = fd->selectedFiles();
		}
        	if ( listsfile.empty() == true )
        	{
        	}
        	else
        	{
			pb_img_magick->setValue(0);
			pb_img_magick->setMaximum(listsfile.count());
			int nbre_new = 0;
			int must_swap = 0;
			must_redraw = 0;
            		QString myfic;
            		QStringList::Iterator mystrlis = listsfile.begin();
            		myfic = *mystrlis;
			//
            		int i = myfic.lastIndexOf( '/' );
            		if ( i != -1 )
            		{
                		path_photos_import = myfic.mid(0,i);
            		}
			//
			if ( current_diapo < nbre_photos )
			{
				must_swap = 1;
			}
			//
			QImage wl_pix_1;
			QPixmap wl_pix_2(97,77);
			QImage wl_pix_3;
			QImage wl_pix_4;
			QPainter p;
			QIcon myicon;
			QString outfilename;
			int wl_random_value;
	
			while( mystrlis != listsfile.end() && nbre_photos < 399 )
            		{
        			myfic = *mystrlis;

				if ( wl_pix_1.load(myfic) == true )
				{
					if ( lst_transitions_2->currentIndex() == 1 )
					{
						wl_random_value = rand()%(lst_transitions_2->count() - 1);
						if ( wl_random_value < 2 )
						{
							wl_random_value = 2;
						}
					}
					else
					{
						if ( lst_transitions_2->currentIndex() > 0 )
						{
							wl_random_value = lst_transitions_2->currentIndex() - 1;
						}
						else
						{
							wl_random_value = 0;
						}
					}
					// *** Creation de la miniature pour la timeline ***
					wl_pix_2 = wg_diapositive;
					myicon = lst_transitions->itemIcon(wl_random_value);
            				i = myfic.lastIndexOf( '/' );
                			outfilename = myfic.mid(i + 1, myfic.length() - (i + 1));
					if ( wl_pix_1.height() > wl_pix_1.width() )
					{
						wl_pix_3 = wl_pix_1.scaledToHeight ( 63, Qt::FastTransformation );
						/*if ( wl_pix_1.height() > 576 )
						{
							wl_pix_4 = wl_pix_1.scaledToHeight ( 576, Qt::FastTransformation );
							wl_pix_4.save(wpathprojet + "/" + outfilename);
						}
						else
						{
							QFile::copy ( myfic, wpathprojet + "/" + outfilename );
						}*/
					}
					else
					{
						wl_pix_3 = wl_pix_1.scaledToWidth ( 83, Qt::FastTransformation );
						/*if ( wl_pix_1.width() > 720 )
						{
							wl_pix_4 = wl_pix_1.scaledToHeight ( 720, Qt::FastTransformation );
							wl_pix_4.save(wpathprojet + "/" + outfilename);
						}
						else
						{
							QFile::copy ( myfic, wpathprojet + "/" + outfilename );
						}*/
					}
					QFile::copy ( myfic, wpathprojet + "/" + outfilename );
        				p.begin(&wl_pix_2);
					p.drawImage(7 + ((83 - wl_pix_3.width()) / 2), 7 + ((63 - wl_pix_3.height()) / 2), wl_pix_3, 0, 0, 83, 63 );
					if ( wl_random_value > 0 )
					{
						myicon.paint ( &p, 56, 45, 32, 24, Qt::AlignCenter, QIcon::Normal, QIcon::On );
					}
					p.end();
					nbre_new = nbre_new + 1;
					//
					nbre_photos = nbre_photos + 1;
					table_photos[nbre_photos][0] = outfilename;
					table_photos[nbre_photos][1] = "0";
					table_photos[nbre_photos][2] = "0";
					table_photos[nbre_photos][3] = "-3.8";
					table_photos[nbre_photos][4] = "0";
					table_photos[nbre_photos][5] = "0";
					table_photos[nbre_photos][6] = "0";
					table_photos[nbre_photos][7] = "0";
					table_photos[nbre_photos][8] = "0";
					table_photos[nbre_photos][9] = "-3.8";
					table_photos[nbre_photos][10] = "0";
					table_photos[nbre_photos][11] = "0";
					table_photos[nbre_photos][12] = "0";
					table_photos[nbre_photos][13] = "$N$U$L$L";
					table_photos[nbre_photos][14] = "0";
					table_photos[nbre_photos][15] = "30";
					table_photos[nbre_photos][16] = QString::number(spindurdiapo_2->value());
					table_photos[nbre_photos][17] = "";
					table_photos[nbre_photos][18] = "0";
					table_photos[nbre_photos][19] = "0";
					table_photos[nbre_photos][20] = QString::number(wl_random_value);
					table_photos[nbre_photos][21] = QString::number(spindurtrans_2->value());
					table_photos[nbre_photos][22] = "0";
					table_photos[nbre_photos][23] = "0";
					table_photos[nbre_photos][24] = "";
					table_photos[nbre_photos][25] = "60";
					table_photos[nbre_photos][26] = "60";
					table_photos[nbre_photos][27] = "0";
					table_photos[nbre_photos][28] = "30";
					table_photos[nbre_photos][29] = "0";
					table_photos[nbre_photos][30] = "1";
					table_photos[nbre_photos][31] = "0;20";
					table_photos[nbre_photos][32] = "100";
					table_color_fog[nbre_photos] = QColor(128,128,128);
					//
       					QLabel *mylabel = new QLabel(timeline);
					mylabel->installEventFilter(this);
					table_pnt_img[nbre_photos] = mylabel;
       					mylabel->setGeometry( ((nbre_photos * 97) + (nbre_photos * 10)), 0, 97, 77);
       					mylabel->setPixmap ( wl_pix_2 );
       					mylabel->show();
				}
				else
				{
					QMessageBox::information(this, "Manslide", tr("Echec du chargement de l'image : ") + myfic);
				}
				//
				pb_img_magick->setValue(pb_img_magick->value() + 1);
				++mystrlis;
			}
			//
			if ( must_swap == 1 )
			{
				int oldpos = nbre_photos - nbre_new;
				int newpos = 0;
				int posbcl = 0;
				int bclimg = 1;
				while ( bclimg <= nbre_new )
				{
					posbcl = oldpos + bclimg;

					while ( posbcl > current_diapo + 1 )
					{
						f_swap_swap(posbcl, posbcl - 1);
						posbcl--;
					}

					bclimg++;
				}
			}
			else
			{
				current_diapo = nbre_photos;
			}
			img_selection->show();
			img_selection->setGeometry( ((nbre_photos * 97) + (nbre_photos * 10)), 0, 97, 77);
			img_selection->raise();
			//
			if ( ((nbre_photos + 1) * 110) - 740 > 0 )
			{
				scroll_timeline->setMaximum(((nbre_photos + 1) * 110) - 740);
			}
			else
			{
				scroll_timeline->setMaximum(0);
			}
			//
			if ( nbre_photos >= 0 )
			{
				if ( nbre_new > 0 )
				{
					pntmygl->txt_sur_image = table_photos[current_diapo][17];
					pntmygl->wg_duree = spindurdiapo_2->value();
					pntmygl->pause_debut = 0;
					pntmygl->pause_fin = 0;
					comboposlegende->setCurrentIndex(0);
					spindurdiapo->setValue(spindurdiapo_2->value());
					spindurtrans->setMaximum(5);
					spindurtrans->setValue(spindurtrans_2->value());
					lst_transitions->setCurrentIndex(table_photos[current_diapo][20].toInt());
				}
				//
				group_support->setEnabled(true);
				bt_start_new->setEnabled(true);
				bt_save_proj->setEnabled(true);
				bt_supprime_diapo->setEnabled(true);
				frame_ed3d->setEnabled(true);
				bt_copy_all->setEnabled(true);
				bt_play->setEnabled(true);
				bt_play_all->setEnabled(true);
				bt_stop->setEnabled(true);
				bt_start->setEnabled(true);
				bt_end->setEnabled(true);
				param_diapo->setEnabled(true);
				bt_img_effects->setEnabled(true);
				bt_fond->setEnabled(true);
				bt_screenshot->setEnabled(true);
				frame_toptimeline->setEnabled(true);
				contain_timeline->setEnabled(true);
				affichage_diapo();
				f_calcul_son();
			}
		}
        }
	else
	{
		QMessageBox::information(this, "Manslide", tr("le nombre maximum de diapos est de 400. Desole ..."));
	}
}

void mainfrm::f_scroll_timeline(int valeur)
{
	if (valeur >= 0)
	{
		timeline->setGeometry(0-valeur,0,50000,112);
	}
}

void mainfrm::keyPressEvent( QKeyEvent *k )
{
// *** Gestion du clavier *** 
    	if ( k->key() == Qt::Key_Escape)
    	{
    	}
}

bool mainfrm::eventFilter(QObject *o, QEvent *e)
{
// ***************************
// *** Filtrage des events ***
// ***************************
    	if ( contain_timeline->isEnabled() == true )
    	{
        	if (e->type() == QEvent::MouseButtonPress )
        	{
            		int i = 0;
            		while (table_pnt_img[i] != o && i < 400)
            		{
                		i = i + 1;
            		}
            		if (table_pnt_img[i] == o)
            		{
				must_redraw = 0;
				current_diapo = i;
                		affichage_diapo();
            		}
        	}
	}
	return QDialog::eventFilter(o,e);
}

void mainfrm::affichage_diapo()
{
	pntmygl->type3D = table_photos[current_diapo][27].toInt();
	if ( table_photos[current_diapo][27] == "0" )
	{
		plane->setChecked(true);
	}
	else
	{
		if ( table_photos[current_diapo][27] == "1" )
		{
			flag->setChecked(true);
		}
		else
		{
			if ( table_photos[current_diapo][27] == "2" )
			{
				cube->setChecked(true);
			}
		}
	}
	if ( table_photos[current_diapo][31].mid(0,1) == "1" )
	{
		inverser->setChecked(true);
	}
	else
	{
		inverser->setChecked(false);
	}
	outfilename = table_photos[current_diapo][31].mid(2,table_photos[current_diapo][31].length() - 2);
	slider_smooth->setValue(outfilename.toInt());

	lcdcurrent->display(current_diapo + 1);
	pntmygl->txt_sur_image = table_photos[current_diapo][17];
	legende_image->setText(table_photos[current_diapo][17]);
	pntmygl->effet_titre = table_photos[current_diapo][23].toInt();
	comboposlegende->setCurrentIndex(table_photos[current_diapo][23].toInt());
       	pntmygl->debut_px = table_photos[current_diapo][1].toFloat();
       	pntmygl->debut_py = table_photos[current_diapo][2].toFloat();
       	pntmygl->debut_pz = table_photos[current_diapo][3].toFloat();
       	pntmygl->debut_rx = table_photos[current_diapo][4].toFloat();
       	pntmygl->debut_ry = table_photos[current_diapo][5].toFloat();
       	pntmygl->debut_rz = table_photos[current_diapo][6].toFloat();
	//
       	pntmygl->fin_px = table_photos[current_diapo][7].toFloat();
       	pntmygl->fin_py = table_photos[current_diapo][8].toFloat();
       	pntmygl->fin_pz = table_photos[current_diapo][9].toFloat();
       	pntmygl->fin_rx = table_photos[current_diapo][10].toFloat();
       	pntmygl->fin_ry = table_photos[current_diapo][11].toFloat();
       	pntmygl->fin_rz = table_photos[current_diapo][12].toFloat();
	//
	pntmygl->rotationX = table_photos[current_diapo][4].toFloat();
	pntmygl->rotationY = table_photos[current_diapo][5].toFloat();
	pntmygl->rotationZ = table_photos[current_diapo][6].toFloat();
	pntmygl->zoom = table_photos[current_diapo][3].toFloat();
	pntmygl->deplacementX = table_photos[current_diapo][1].toFloat();
	pntmygl->deplacementY = table_photos[current_diapo][2].toFloat();
	pntmygl->path_fond = table_photos[current_diapo][13];
	pntmygl->wg_percent = table_photos[current_diapo][25].toFloat() / 100;
	pntmygl->wg_percent_slide = table_photos[current_diapo][32].toFloat() / 100;
	dial_percent_blending->setValue(table_photos[current_diapo][25].toInt());
	dial_percent_blending_2->setValue(table_photos[current_diapo][26].toInt());
	dial_opacity_slide->setValue(table_photos[current_diapo][32].toInt());
	slider_factor->setValue(table_photos[current_diapo][30].toInt());
	pntmygl->size_factor = table_photos[current_diapo][30].toInt();
	label_percent_1->setText( table_photos[current_diapo][25] + " %");
	label_percent_2->setText( table_photos[current_diapo][26] + " %");
	if ( table_photos[current_diapo][29] == "1" )
	{
		pntmygl->isbackanim = 1;
		check_backanim->setChecked(true);
	}
	else
	{
		pntmygl->isbackanim = 0;
		check_backanim->setChecked(false);
	}
	//
	if ( table_photos[current_diapo][14] == "1" )
	{
		pntmygl->fogcolor[0] = (float)table_color_fog[current_diapo].red() / (float)255;
		pntmygl->fogcolor[1] = (float)table_color_fog[current_diapo].green() / (float)255;
		pntmygl->fogcolor[2] = (float)table_color_fog[current_diapo].blue() / (float)255;
		pntmygl->fogcolor[3] = 0.5;
		pntmygl->isfog = 1;
		check_fog->setChecked(true);
		dial_opacity->setValue(table_photos[current_diapo][15].toInt());
		dial_opacity_2->setValue(table_photos[current_diapo][28].toInt());
		pntmygl->change_fog_color();
	}
	else
	{
		pntmygl->isfog = 0;
		dial_opacity->setValue(30);
		dial_opacity_2->setValue(30);
		check_fog->setChecked(false);
	}
	//
	pntmygl->wg_duree = table_photos[current_diapo][16].toInt();
	spindurpausefirst->setValue(table_photos[current_diapo][19].toInt());
	spindurpauselast->setValue(table_photos[current_diapo][18].toInt());
	//
	if ( table_photos[current_diapo][22] != "0" )
	{
		int idxsearch = 1;
		QString nomeffet = table_photos[current_diapo][22];
		while ( nomeffet != pntmygl->table_effets[idxsearch][0] && idxsearch < 39 )
		{
			idxsearch = idxsearch + 1;
		}
		if ( idxsearch < 39 )
		{
			comboeffets->setCurrentIndex(idxsearch);
		}
		else
		{
			comboeffets->setCurrentIndex(0);
		}
	}
	else
	{
		comboeffets->setCurrentIndex(0);
	}
	//
	spindurdiapo->setValue(table_photos[current_diapo][16].toInt());
	spindurtrans->setMaximum(table_photos[current_diapo][16].toInt());
	spindurtrans->setValue(table_photos[current_diapo][21].toInt());
	//
	title_comment->setText(table_photos[current_diapo][24]);
	//
	if ( table_photos[current_diapo][20] == "0" )
	{
		lst_transitions->setCurrentIndex(0);
		bt_param_trans->setDisabled(true);
	}
	else
	{
		if ( table_photos[current_diapo][20].toInt() > 1 )
		{
			bt_param_trans->setEnabled(true);
		}
		else
		{
			bt_param_trans->setDisabled(true);
		}
		lst_transitions->setCurrentIndex(table_photos[current_diapo][20].toInt());
	}
	//
	pntmygl->wg_duree = table_photos[current_diapo][16].toInt();
	pntmygl->pause_debut = table_photos[current_diapo][19].toInt();
	pntmygl->pause_fin = table_photos[current_diapo][18].toInt();
	pntmygl->sl_charge_image(wpathprojet + "/" + table_photos[current_diapo][0], wpathprojet + "/" + table_photos[current_diapo][13]);
	pntmygl->updateGL();
	//
	position_flux = 0;
	//
	img_selection->setGeometry( ((current_diapo * 97) + (current_diapo * 10)), 0, 97, 77);
}

void mainfrm::f_transition_changed(int myindex)
{
	if ( nbre_photos >= 0 && must_redraw == 0 )
	{
		QLabel *mylabel;
		mylabel = table_pnt_img[current_diapo];
		QImage wl_pix_1(wpathprojet + "/" + table_photos[current_diapo][0]);
		QPixmap wl_pix_2(wg_diapositive);
		QImage wl_pix_3;
		if ( wl_pix_1.height() > wl_pix_1.width() )
		{
			wl_pix_3 = wl_pix_1.scaledToHeight ( 63, Qt::FastTransformation );
		}
		else
		{
			wl_pix_3 = wl_pix_1.scaledToWidth ( 83, Qt::FastTransformation );
		}
		QPainter p;
		p.begin(&wl_pix_2);
		p.drawImage(7 + ((83 - wl_pix_3.width()) / 2), 7 + ((63 - wl_pix_3.height()) / 2), wl_pix_3, 0, 0, 83, 63 );
		QIcon myicon = lst_transitions->itemIcon(myindex);
		myicon.paint ( &p, 56, 45, 32, 24, Qt::AlignCenter, QIcon::Normal, QIcon::On );
		if ( table_photos[current_diapo][24] != "" )
		{
			p.drawPixmap(2, 57, wg_comment, 0, 0, -1, -1 );
		}
		p.end();
		mylabel->setPixmap(wl_pix_2);
		//
		table_photos[current_diapo][20] = QString::number(myindex);
		if ( myindex > 1 )
		{
			bt_param_trans->setEnabled(true);
		}
		else
		{
			bt_param_trans->setDisabled(true);
		}
	}
}

void mainfrm::f_transition_duree_changed(int myduree)
{
	table_photos[current_diapo][21] = QString::number(myduree);
}

void mainfrm::start_play_all()
{
	bt_play->setDisabled(true);
	bt_play_all->setDisabled(true);
	bt_start->setDisabled(true);
	bt_end->setDisabled(true);
	frame_toptimeline->setDisabled(true);
	//
	frame_parametres->hide();
	frame_topmenu->setDisabled(true);
	frame_parameters->setDisabled(true);
	frame_telecomm->setDisabled(true);
	frame_zik->setDisabled(true);
	menu_images->setDisabled(true);
	menu_projet->setDisabled(true);
	param_encoding->setDisabled(true);
	contain_timeline->setDisabled(true);
	//
	pntmygl->type_play = 1; 
	pntmygl->wg_duree = table_photos[current_diapo][16].toInt();
	pntmygl->txt_sur_image = table_photos[current_diapo][17];
	pntmygl->effet_titre = table_photos[current_diapo][23].toInt();
	pntmygl->pause_debut = spindurpausefirst->value();
	pntmygl->pause_fin = spindurpauselast->value();
	pntmygl->start_opacity = table_photos[current_diapo][25].toFloat() / 100;
	pntmygl->end_opacity = table_photos[current_diapo][26].toFloat() / 100;
	pntmygl->wg_percent_slide = table_photos[current_diapo][32].toFloat() / 100;
	//
	pntmygl->duree = pntmygl->wg_duree * 25;
	pntmygl->progress = 0;
	pntmygl->progress_anim = 1;
	pntmygl->x_titre = -1.8;
	pntmygl->delta_px = (pntmygl->fin_px - pntmygl->debut_px) / (pntmygl->duree-1);
	pntmygl->delta_py = (pntmygl->fin_py - pntmygl->debut_py) / (pntmygl->duree-1);
	pntmygl->delta_pz = (pntmygl->fin_pz - pntmygl->debut_pz) / (pntmygl->duree-1);
	pntmygl->delta_rx = (pntmygl->fin_rx - pntmygl->debut_rx) / (pntmygl->duree-1);
	pntmygl->delta_ry = (pntmygl->fin_ry - pntmygl->debut_ry) / (pntmygl->duree-1);
	pntmygl->delta_rz = (pntmygl->fin_rz - pntmygl->debut_rz) / (pntmygl->duree-1);
    	pntmygl->rotationX = pntmygl->debut_rx;
    	pntmygl->rotationY = pntmygl->debut_ry;
    	pntmygl->rotationZ = pntmygl->debut_rz;
    	pntmygl->deplacementX = pntmygl->debut_px;
    	pntmygl->deplacementY = pntmygl->debut_py;
	pntmygl->zoom = pntmygl->debut_pz;
	pntmygl->poursuite = 0;
	pntmygl->delta_opacity = (pntmygl->end_opacity - pntmygl->start_opacity) / (pntmygl->duree-1);
	pntmygl->wg_percent = pntmygl->start_opacity;
	pntmygl->start_fog_opacity = table_photos[current_diapo][15].toFloat();
	pntmygl->end_fog_opacity = table_photos[current_diapo][28].toFloat();
	pntmygl->isfog = table_photos[current_diapo][14].toFloat();
	pntmygl->delta_fog_opacity = (pntmygl->end_fog_opacity - pntmygl->start_fog_opacity) / (pntmygl->duree-1);
	pntmygl->wg_percent_fog = pntmygl->start_fog_opacity;
	QTimer::singleShot(0, this, SLOT(f_updateMove()));
}

void mainfrm::f_updateMove()
{
	if ( pntmygl->progress >= pntmygl->duree + (pntmygl->pause_debut * 25) + (pntmygl->pause_fin * 25) )
	{
		current_diapo = current_diapo + 1;
		if ( current_diapo > nbre_photos )
		{
			current_diapo = 0;
		}
		affichage_diapo();
		start_play_all();
		return;
	}
	else
	{
		if ( pntmygl->progress >= (pntmygl->pause_debut * 25) && pntmygl->progress <= (pntmygl->pause_debut * 25) + pntmygl->duree)
		{
    			pntmygl->rotationX = pntmygl->rotationX + pntmygl->delta_rx;
    			pntmygl->rotationY = pntmygl->rotationY + pntmygl->delta_ry;
    			pntmygl->rotationZ = pntmygl->rotationZ + pntmygl->delta_rz;
    			pntmygl->deplacementX = pntmygl->deplacementX + pntmygl->delta_px;
    			pntmygl->deplacementY = pntmygl->deplacementY + pntmygl->delta_py;
			pntmygl->zoom = pntmygl->zoom + pntmygl->delta_pz;
			pntmygl->wg_percent = pntmygl->wg_percent + pntmygl->delta_opacity;
			pntmygl->wg_percent_fog = pntmygl->wg_percent_fog + pntmygl->delta_fog_opacity;

			if ( pntmygl->effet_titre == 4 )
			{
				if ( pntmygl->x_titre + 0.82 < -0.8f )
				{
					pntmygl->x_titre = pntmygl->x_titre + 0.03;
					pntmygl->y_titre = pntmygl->y_titre - 6;
				}
			}
		}
	}
	if ( pntmygl->effet_titre == 3 )
	{
		pntmygl->x_titre = pntmygl->x_titre + pntmygl->v_titre;
	}
	if ( pntmygl->iseffect > 0 )
	{
		if (pntmygl->progress_anim < pntmygl->maxanim)
		{
			pntmygl->progress_anim = pntmygl->progress_anim + 1;
		}
		else
		{
			pntmygl->progress_anim = 1;
		}
		QString	wl_var_1 = "000000";
		QString	wl_var_2 = QString::number(pntmygl->progress_anim);
		wl_var_1.replace( 6 - wl_var_2.length(), wl_var_2.length(), wl_var_2);
		glDeleteTextures( 1, &pntmygl->texture3 );
		if ( pntmygl->a.load(pntmygl->wg_tet_library + "/BIB_ManSlide/Effects/" + pntmygl->nameanim + wl_var_1 + ".jpg") == true )
		{
			pntmygl->d = QGLWidget::convertToGLFormat( pntmygl->a );
		}
		else
		{
			pntmygl->d = QGLWidget::convertToGLFormat( pntmygl->null_img );
		}
		glGenTextures( 1, &pntmygl->texture3 );
		glBindTexture( GL_TEXTURE_2D, pntmygl->texture3 );
		glTexImage2D( GL_TEXTURE_2D, 0, 4, pntmygl->d.width(), pntmygl->d.height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, pntmygl->d.bits() );
		glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST );
	}

	if ( pntmygl->isfog == 1 )
	{
		pntmygl->sl_opacity(pntmygl->wg_percent_fog);
	}

	if ( pntmygl->poursuite == 0 )
	{
		pntmygl->progress = pntmygl->progress + 1;
		pntmygl->updateGL();
		QTimer::singleShot(40, this, SLOT(f_updateMove()));
	}
	else
	{
		pntmygl->rotationX = pntmygl->debut_rx;
		pntmygl->rotationY = pntmygl->debut_ry;
		pntmygl->rotationZ = pntmygl->debut_rz;
		pntmygl->deplacementX = pntmygl->debut_px;
		pntmygl->deplacementY = pntmygl->debut_py;
		pntmygl->zoom = pntmygl->debut_pz;
		pntmygl->wg_percent = pntmygl->start_opacity;
		pntmygl->x_titre = -1.8;
		pntmygl->updateGL();
	}
}

void mainfrm::start_play()
{
	bt_play->setDisabled(true);
	bt_play_all->setDisabled(true);
	bt_start->setDisabled(true);
	bt_end->setDisabled(true);
	frame_toptimeline->setDisabled(true);
	//
	frame_parametres->hide();
	frame_topmenu->setDisabled(true);
	frame_parameters->setDisabled(true);
	frame_telecomm->setDisabled(true);
	frame_zik->setDisabled(true);
	menu_images->setDisabled(true);
	menu_projet->setDisabled(true);
	param_encoding->setDisabled(true);
	contain_timeline->setDisabled(true);
	//
	pntmygl->type_play = 0;
	pntmygl->isfog = table_photos[current_diapo][14].toInt();
	pntmygl->wg_duree = table_photos[current_diapo][16].toInt();
	pntmygl->txt_sur_image = table_photos[current_diapo][17];
	pntmygl->effet_titre = table_photos[current_diapo][23].toInt();
	pntmygl->pause_debut = spindurpausefirst->value();
	pntmygl->pause_fin = spindurpauselast->value();
	pntmygl->start_opacity = table_photos[current_diapo][25].toFloat() / 100;
	pntmygl->end_opacity = table_photos[current_diapo][26].toFloat() / 100;
	pntmygl->start_fog_opacity = table_photos[current_diapo][15].toFloat();
	pntmygl->end_fog_opacity = table_photos[current_diapo][28].toFloat();
	pntmygl->sl_play();
}

void mainfrm::stop_play()
{
	position_flux = 0; 
	bt_play->setEnabled(true);
	bt_play_all->setEnabled(true);
	bt_start->setEnabled(true);
	bt_end->setEnabled(true);
	frame_toptimeline->setEnabled(true);
	pntmygl->sl_stop();
	//
	frame_topmenu->setEnabled(true);
	frame_parameters->setEnabled(true);
	frame_telecomm->setEnabled(true);
	frame_zik->setEnabled(true);
	menu_images->setEnabled(true);
	menu_projet->setEnabled(true);
	param_encoding->setEnabled(true);
	contain_timeline->setEnabled(true);
}
